@@ -91,7 +91,7 @@ bool FormatFont::isNull() const
   return d->null;
 }
 
-UString FormatFont::fontFamily() const
+const UString& FormatFont::fontFamily() const
 {
   return d->fontFamily;
 }
@@ -279,6 +279,11 @@ FormatAlignment& FormatAlignment::assign( const FormatAlignment& align )
   return *this;
 }
 
+bool FormatAlignment::isNull() const
+{
+  return d->null;
+}
+
 unsigned FormatAlignment::alignX() const
 {
   return d->alignX;
@@ -615,11 +620,6 @@ Format& Format::assign( const Format& f )
   return *this;
 }
 
-bool FormatAlignment::isNull() const
-{
-  return d->null;
-}
-
 bool Format::isNull() const
 {
   return d->font.isNull() && d->alignment.isNull() && d->borders.isNull();
@@ -665,7 +665,7 @@ void Format::setBackground( const FormatBackground& background )
   d->background = background;
 }
 
-UString Format::valueFormat() const
+const UString& Format::valueFormat() const
 {
   return d->valueFormat;
 }
