@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <float.h>
@@ -30,18 +30,19 @@
 #include "opencalcimport.h"
 
 #include <kdebug.h>
-#include <koDocumentInfo.h>
+#include <KoDocumentInfo.h>
 #include <kgenericfactory.h>
 #include <kmessagebox.h>
 #include <kmdcodec.h>
-#include <koFilterChain.h>
-#include <koGlobal.h>
-#include <koUnit.h>
-#include <koStyleStack.h>
-#include <kodom.h>
+#include <KoFilterChain.h>
+#include <KoGlobal.h>
+#include <KoUnit.h>
+#include <KoStyleStack.h>
+#include <KoDom.h>
 #include <ooutils.h>
 
 #include <kspread_cell.h>
+#include <kspread_condition.h>
 #include <kspread_doc.h>
 #include <kspread_global.h>
 #include <kspread_map.h>
@@ -54,6 +55,8 @@
 
 #define SECSPERDAY (24 * 60 * 60)
 
+using namespace KSpread;
+
 class OpenCalcImportFactory : KGenericFactory<OpenCalcImport, KoFilter>
 {
 public:
@@ -113,17 +116,17 @@ OpenCalcImport::OpenCalcPoint::OpenCalcPoint( QString const & str )
 
   if ( isRange )
   {
-    KSpreadRange newRange( range );
-    table    = newRange.sheetName;
-    topLeft  = newRange.range.topLeft();
-    botRight = newRange.range.bottomRight();
+	  KSpread::Range newRange( range );
+    table    = newRange.sheetName();
+    topLeft  = newRange.range().topLeft();
+    botRight = newRange.range().bottomRight();
   }
   else
   {
-    KSpreadPoint newPoint( range );
-    table    = newPoint.sheetName;
-    topLeft  = newPoint.pos;
-    botRight = newPoint.pos;
+    Point newPoint( range );
+    table    = newPoint.sheetName();
+    topLeft  = newPoint.pos();
+    botRight = newPoint.pos();
   }
 }
 
@@ -150,7 +153,7 @@ double timeToNum( int h, int m, int s )
 }
 
 bool OpenCalcImport::readRowFormat( QDomElement & rowNode, QDomElement * rowStyle,
-                                    KSpreadSheet * table, int & row, int & number,
+                                    Sheet * table, int & row, int & number,
                                     bool isLast )
 {
   if ( rowNode.isNull() )
@@ -165,7 +168,7 @@ bool OpenCalcImport::readRowFormat( QDomElement & rowNode, QDomElement * rowStyl
 
   double height = -1.0;
   bool insertPageBreak = false;
-  KSpreadFormat layout( table, table->doc()->styleManager()->defaultStyle() );
+  Format layout( table, table->doc()->styleManager()->defaultStyle() );
 
   while( !node.isNull() )
   {
@@ -221,7 +224,7 @@ bool OpenCalcImport::readRowFormat( QDomElement & rowNode, QDomElement * rowStyl
     if ( height != -1 )
     {
       kdDebug(30518) << "Setting row height to " << height << endl;
-      rowL->setHeight( height );
+      rowL->setHeight( int( height ) );
     }
 
     // if ( insertPageBreak ) TODO:
@@ -357,13 +360,6 @@ void OpenCalcImport::convertFormula( QString & text, QString const & f ) const
       else
         parameter += "==";
     }
-    else if ( f[p] == '%' )
-    {
-      if( inQuote )
-        parameter += '%';
-      else
-        parameter += "/100";
-    }
     else if ( f[p] == ')' )
     {
       if ( !inQuote )
@@ -381,12 +377,12 @@ void OpenCalcImport::convertFormula( QString & text, QString const & f ) const
   kdDebug(30518) << "New formula: " << text << endl;
 }
 
-bool OpenCalcImport::readCells( QDomElement & rowNode, KSpreadSheet  * table, int row, int & columns )
+bool OpenCalcImport::readCells( QDomElement & rowNode, Sheet  * table, int row, int & columns )
 {
   bool ok = true;
   int spanC = 1;
   int spanR = 1;
-  //KSpreadCell * defCell = table->defaultCell();
+  //Cell* defCell = table->defaultCell();
 
   QDomNode cellNode = KoDom::namedItemNS( rowNode, ooNS::table, "table-cell" );
 
@@ -403,7 +399,7 @@ bool OpenCalcImport::readCells( QDomElement & rowNode, KSpreadSheet  * table, in
       continue;
     }
 
-    KSpreadCell * cell = 0;
+    Cell* cell = 0;
 
     kdDebug(30518) << " Cell: " << columns << ", " << row << endl;
 
@@ -467,7 +463,7 @@ bool OpenCalcImport::readCells( QDomElement & rowNode, KSpreadSheet  * table, in
             if ( !cell )
                 cell = table->nonDefaultCell( columns, row );
             kdDebug(30518)<<" columns :"<<columns<<" row :"<<row<<endl;
-            cell->setComment( comment );
+            cell->format()->setComment( comment );
         }
     }
 
@@ -484,10 +480,10 @@ bool OpenCalcImport::readCells( QDomElement & rowNode, KSpreadSheet  * table, in
         psName = e.attributeNS( ooNS::style, "parent-style-name", QString::null );
 
       kdDebug(30518) << "Default style: " << psName << endl;
-      KSpreadFormat * layout = m_defaultStyles[psName];
+      Format * layout = m_defaultStyles[psName];
 
       if ( layout )
-        cell->copy( *layout );
+        cell->format()->copy( *layout );
 
       QDomElement * st = 0;
       if ( e.hasAttributeNS( ooNS::table, "style-name" ) )
@@ -513,11 +509,11 @@ bool OpenCalcImport::readCells( QDomElement & rowNode, KSpreadSheet  * table, in
             }
             if ( property.localName() == "properties" && property.namespaceURI() == ooNS::style )
             {
-              loadStyleProperties( cell, property );
-              if ( cell->getAngle( columns, row ) != 0 )
+              loadStyleProperties( cell->format(), property );
+              if ( cell->format()->getAngle( columns, row ) != 0 )
               {
-                QFontMetrics fm( cell->textFont( columns, row ) );
-                int tmpAngle = cell->getAngle( columns, row );
+                QFontMetrics fm( cell->format()->textFont( columns, row ) );
+                int tmpAngle = cell->format()->getAngle( columns, row );
                 int textHeight = static_cast<int>( cos( tmpAngle * M_PI / 180 )
                                                    * ( fm.ascent() + fm.descent() )
                                                    + abs ( ( int )(  fm.width( cell->strOutText() )
@@ -552,10 +548,10 @@ bool OpenCalcImport::readCells( QDomElement & rowNode, KSpreadSheet  * table, in
 
       QString psName( "Default" );
       kdDebug(30518) << "Default style: " << psName << endl;
-      KSpreadFormat * layout = m_defaultStyles[psName];
+      Format * layout = m_defaultStyles[psName];
 
       if ( layout )
-        cell->copy( *layout );
+        cell->format()->copy( *layout );
     }
     if ( e.hasAttributeNS( ooNS::table, "formula" ) )
     {
@@ -597,8 +593,8 @@ bool OpenCalcImport::readCells( QDomElement & rowNode, KSpreadSheet  * table, in
 
           if ( type == "currency" )
           {
-            cell->setCurrency( 1, e.attributeNS( ooNS::table, "currency", QString::null ) );
-            cell->setFormatType( Money_format );
+            cell->format()->setCurrency( 1, e.attributeNS( ooNS::table, "currency", QString::null ) );
+            cell->format()->setFormatType( Money_format );
           }
         }
       }
@@ -613,7 +609,7 @@ bool OpenCalcImport::readCells( QDomElement & rowNode, KSpreadSheet  * table, in
             //TODO fixme
 			//cell->setFactor( 100 );
             // TODO: replace with custom...
-            cell->setFormatType( Percentage_format );
+            cell->format()->setFormatType( Percentage_format );
           }
         }
         else if ( type == "boolean" )
@@ -627,7 +623,7 @@ bool OpenCalcImport::readCells( QDomElement & rowNode, KSpreadSheet  * table, in
           else
             cell->setValue( false );
           ok = true;
-          cell->setFormatType( Custom_format );
+          cell->format()->setFormatType( Custom_format );
         }
         else if ( type == "date" )
         {
@@ -707,7 +703,7 @@ bool OpenCalcImport::readCells( QDomElement & rowNode, KSpreadSheet  * table, in
             // KSpreadValue kval( timeToNum( hours, minutes, seconds ) );
             // cell->setValue( kval );
             cell->setValue( QTime( hours % 24, minutes, seconds ) );
-            cell->setFormatType( Custom_format );
+            cell->format()->setFormatType( Custom_format );
           }
         }
 
@@ -726,7 +722,7 @@ bool OpenCalcImport::readCells( QDomElement & rowNode, KSpreadSheet  * table, in
     {
       if ( !cell )
         cell = table->nonDefaultCell( columns, row );
-      cell->forceExtraCells( columns, row, spanC - 1, spanR - 1 );
+      cell->mergeCells( columns, row, spanC - 1, spanR - 1 );
     }
 
     cellNode = cellNode.nextSibling();
@@ -736,7 +732,7 @@ bool OpenCalcImport::readCells( QDomElement & rowNode, KSpreadSheet  * table, in
       // copy cell from left
       bool ok = false;
       int number = e.attributeNS( ooNS::table, "number-columns-repeated", QString::null ).toInt( &ok );
-      KSpreadCell * cellDest = 0;
+      Cell* cellDest = 0;
 
       // don't repeat more than 10 if it is the last cell and empty
       if ( !ok || cellNode.isNull() )
@@ -764,18 +760,18 @@ bool OpenCalcImport::readCells( QDomElement & rowNode, KSpreadSheet  * table, in
 }
 
 
-void OpenCalcImport::loadCondition( KSpreadCell *cell,const QDomElement &property )
+void OpenCalcImport::loadCondition( Cell*cell,const QDomElement &property )
 {
-    kdDebug(30518)<<"void OpenCalcImport::loadCondition( KSpreadCell *cell,const QDomElement &property )*******\n";
+    kdDebug(30518)<<"void OpenCalcImport::loadCondition( Cell*cell,const QDomElement &property )*******\n";
     loadOasisCondition( cell, property );
 }
 
-void OpenCalcImport::loadOasisCondition(KSpreadCell *cell,const QDomElement &property )
+void OpenCalcImport::loadOasisCondition(Cell*cell,const QDomElement &property )
 {
     QDomElement elementItem( property );
-    KSpreadStyleManager * manager = cell->sheet()->doc()->styleManager();
+    StyleManager * manager = cell->sheet()->doc()->styleManager();
 
-    QValueList<KSpreadConditional> cond;
+    QValueList<Conditional> cond;
     while ( !elementItem.isNull() )
     {
         kdDebug(30518)<<"elementItem.tagName() :"<<elementItem.tagName()<<endl;
@@ -784,7 +780,7 @@ void OpenCalcImport::loadOasisCondition(KSpreadCell *cell,const QDomElement &pro
         {
             bool ok = true;
             kdDebug(30518)<<"elementItem.attribute(style:condition ) :"<<elementItem.attributeNS( ooNS::style, "condition", QString::null )<<endl;
-            KSpreadConditional newCondition;
+            Conditional newCondition;
             loadOasisConditionValue( elementItem.attributeNS( ooNS::style, "condition", QString::null ), newCondition );
             if ( elementItem.hasAttributeNS( ooNS::style, "apply-style-name" ) )
             {
@@ -808,7 +804,7 @@ void OpenCalcImport::loadOasisCondition(KSpreadCell *cell,const QDomElement &pro
         cell->setConditionList( cond );
 }
 
-void OpenCalcImport::loadOasisConditionValue( const QString &styleCondition, KSpreadConditional &newCondition )
+void OpenCalcImport::loadOasisConditionValue( const QString &styleCondition, Conditional &newCondition )
 {
     QString val( styleCondition );
     if ( val.contains( "cell-content()" ) )
@@ -824,7 +820,7 @@ void OpenCalcImport::loadOasisConditionValue( const QString &styleCondition, KSp
         val = val.remove( ")" );
         QStringList listVal = QStringList::split( "," , val );
         loadOasisValidationValue( listVal, newCondition );
-        newCondition.cond = Between;
+        newCondition.cond = Conditional::Between;
     }
     if ( val.contains( "cell-content-is-not-between(" ) )
     {
@@ -832,45 +828,45 @@ void OpenCalcImport::loadOasisConditionValue( const QString &styleCondition, KSp
         val = val.remove( ")" );
         QStringList listVal = QStringList::split( ",", val );
         loadOasisValidationValue( listVal,newCondition );
-        newCondition.cond = Different;
+        newCondition.cond = Conditional::Different;
     }
 
 }
 
 
-void OpenCalcImport::loadOasisCondition( QString &valExpression, KSpreadConditional &newCondition )
+void OpenCalcImport::loadOasisCondition( QString &valExpression, Conditional &newCondition )
 {
     QString value;
     if (valExpression.find( "<=" )==0 )
     {
         value = valExpression.remove( 0,2 );
-        newCondition.cond = InferiorEqual;
+        newCondition.cond = Conditional::InferiorEqual;
     }
     else if (valExpression.find( ">=" )==0 )
     {
         value = valExpression.remove( 0,2 );
-        newCondition.cond = SuperiorEqual;
+        newCondition.cond = Conditional::SuperiorEqual;
     }
     else if (valExpression.find( "!=" )==0 )
     {
         //add Differentto attribute
         value = valExpression.remove( 0,2 );
-        newCondition.cond = DifferentTo;
+        newCondition.cond = Conditional::DifferentTo;
     }
     else if ( valExpression.find( "<" )==0 )
     {
         value = valExpression.remove( 0,1 );
-        newCondition.cond = Inferior;
+        newCondition.cond = Conditional::Inferior;
     }
     else if(valExpression.find( ">" )==0 )
     {
         value = valExpression.remove( 0,1 );
-        newCondition.cond = Superior;
+        newCondition.cond = Conditional::Superior;
     }
     else if (valExpression.find( "=" )==0 )
     {
         value = valExpression.remove( 0,1 );
-        newCondition.cond = Equal;
+        newCondition.cond = Conditional::Equal;
     }
     else
         kdDebug(30518)<<" I don't know how to parse it :"<<valExpression<<endl;
@@ -890,7 +886,7 @@ void OpenCalcImport::loadOasisCondition( QString &valExpression, KSpreadConditio
 }
 
 
-void OpenCalcImport::loadOasisValidationValue( const QStringList &listVal, KSpreadConditional &newCondition )
+void OpenCalcImport::loadOasisValidationValue( const QStringList &listVal, Conditional &newCondition )
 {
     bool ok = false;
     kdDebug(30518)<<" listVal[0] :"<<listVal[0]<<" listVal[1] :"<<listVal[1]<<endl;
@@ -919,7 +915,7 @@ void OpenCalcImport::loadOasisValidationValue( const QStringList &listVal, KSpre
 }
 
 
-bool OpenCalcImport::readRowsAndCells( QDomElement & content, KSpreadSheet * table )
+bool OpenCalcImport::readRowsAndCells( QDomElement & content, Sheet * table )
 {
   kdDebug(30518) << endl << "Reading in rows " << endl;
 
@@ -928,9 +924,9 @@ bool OpenCalcImport::readRowsAndCells( QDomElement & content, KSpreadSheet * tab
   int columns = 1;
   int backupRow = 1;
   QDomElement * rowStyle = 0;
-  //KSpreadCell * cell = 0;
-  //KSpreadCell * cellDest = 0;
-  //KSpreadCell * defCell = table->defaultCell();
+  //Cell* cell = 0;
+  //Cell* cellDest = 0;
+  //Cell* defCell = table->defaultCell();
   QDomNode rowNode = KoDom::namedItemNS( content, ooNS::table, "table-row" );
 
   while ( !rowNode.isNull() )
@@ -979,7 +975,7 @@ bool OpenCalcImport::readRowsAndCells( QDomElement & content, KSpreadSheet * tab
        *       if so we will probably also need to copy them for repeated col layouts.
       for ( j = 1; j <= columns; ++j )
       {
-        KSpreadCell * cell = table->cellAt( j, backupRow );
+        Cell* cell = table->cellAt( j, backupRow );
 
         kdDebug(30518) << "Cell: " << cell << "DefCell: " << defCell << endl;
         if ( cell && (cell != defCell) )
@@ -1000,7 +996,7 @@ bool OpenCalcImport::readRowsAndCells( QDomElement & content, KSpreadSheet * tab
   return true;
 }
 
-bool OpenCalcImport::readColLayouts( QDomElement & content, KSpreadSheet * table )
+bool OpenCalcImport::readColLayouts( QDomElement & content, Sheet * table )
 {
   kdDebug(30518) << endl << "Reading in columns..." << endl;
 
@@ -1023,7 +1019,7 @@ bool OpenCalcImport::readColLayouts( QDomElement & content, KSpreadSheet * table
     double width   = colWidth;
     bool collapsed = ( e.attributeNS( ooNS::table, "visibility", QString::null ) == "collapse" );
     bool insertPageBreak = false;
-    KSpreadFormat styleLayout( table, table->doc()->styleManager()->defaultStyle() );
+    Format styleLayout( table, table->doc()->styleManager()->defaultStyle() );
 
     kdDebug(30518) << "Check table:number-columns-repeated" << endl;
     if ( e.hasAttributeNS( ooNS::table, "number-columns-repeated" ) )
@@ -1041,7 +1037,7 @@ bool OpenCalcImport::readColLayouts( QDomElement & content, KSpreadSheet * table
     {
       QString n( e.attributeNS( ooNS::table, "default-cell-style-name", QString::null ) );
       kdDebug(30518) << "Has attribute default-cell-style-name: " << n << endl;
-      KSpreadFormat * defaultStyle = m_defaultStyles[ n ];
+      Format * defaultStyle = m_defaultStyles[ n ];
       if ( !defaultStyle )
       {
         QString name = e.attributeNS( ooNS::table, "default-cell-style-name", QString::null );
@@ -1051,7 +1047,7 @@ bool OpenCalcImport::readColLayouts( QDomElement & content, KSpreadSheet * table
 
         if ( st && !st->isNull() )
         {
-          KSpreadFormat * layout = new KSpreadFormat( 0, m_doc->styleManager()->defaultStyle() );
+          Format * layout = new Format( 0, m_doc->styleManager()->defaultStyle() );
 
           readInStyle( layout, *st );
 
@@ -1120,7 +1116,7 @@ bool OpenCalcImport::readColLayouts( QDomElement & content, KSpreadSheet * table
 
       ColumnFormat * col = new ColumnFormat( table, column );
       col->copy( styleLayout );
-      col->setWidth( width );
+      col->setWidth( int( width ) );
 
       // if ( insertPageBreak )
       //   col->setPageBreak( true )
@@ -1189,7 +1185,7 @@ QString getPart( QDomNode const & part )
   return result;
 }
 
-void OpenCalcImport::loadTableMasterStyle( KSpreadSheet * table,
+void OpenCalcImport::loadTableMasterStyle( Sheet * table,
                                            QString const & stylename )
 {
   kdDebug(30518) << "Loading table master style: " << stylename << endl;
@@ -1273,7 +1269,7 @@ void OpenCalcImport::loadTableMasterStyle( KSpreadSheet * table,
   }
 }
 
-void OpenCalcImport::loadOasisMasterLayoutPage( KSpreadSheet * table,KoStyleStack &styleStack )
+void OpenCalcImport::loadOasisMasterLayoutPage( Sheet * table,KoStyleStack &styleStack )
 {
     float left = 0.0;
     float right = 0.0;
@@ -1414,7 +1410,7 @@ bool OpenCalcImport::parseBody( int numOfTables )
   loadOasisAreaName( body.toElement() );
   loadOasisCellValidation( body.toElement() );
 
-  KSpreadSheet * table;
+  Sheet * table;
   QDomNode sheet = KoDom::namedItemNS( body, ooNS::table, "table" );
 
   kdDebug()<<" sheet :"<<sheet.isNull()<<endl;
@@ -1447,8 +1443,8 @@ bool OpenCalcImport::parseBody( int numOfTables )
   int step = (int) ( 80 / numOfTables );
   int progress = 15;
 
-  KSpreadFormat::setGlobalColWidth( MM_TO_POINT( 22.7 ) );
-  KSpreadFormat::setGlobalRowHeight( MM_TO_POINT( 4.3 ) );
+  Format::setGlobalColWidth( MM_TO_POINT( 22.7 ) );
+  Format::setGlobalRowHeight( MM_TO_POINT( 4.3 ) );
   kdDebug(30518) << "Global Height: " << MM_TO_POINT( 4.3 ) << ", Global width: " << MM_TO_POINT( 22.7) << endl;
 
   while ( !sheet.isNull() )
@@ -1474,12 +1470,12 @@ bool OpenCalcImport::parseBody( int numOfTables )
       continue;
     }
 
-    KSpreadFormat * defaultStyle = m_defaultStyles[ "Default" ];
+    Format * defaultStyle = m_defaultStyles[ "Default" ];
     if ( defaultStyle )
     {
-      KSpreadCell * defaultCell = table->defaultCell();
+      Cell* defaultCell = table->defaultCell();
       kdDebug(30518) << "Copy default style to default cell" << endl;
-      defaultCell->copy( *defaultStyle );
+      defaultCell->format()->copy( *defaultStyle );
     }
     table->setDefaultHeight( MM_TO_POINT( 4.3 ) );
     table->setDefaultWidth( MM_TO_POINT( 22.7 ) );
@@ -1527,12 +1523,12 @@ bool OpenCalcImport::parseBody( int numOfTables )
       OpenCalcPoint point( range );
 
       kdDebug(30518) << "Print range: " << point.translation << endl;
-      KSpreadRange p( point.translation );
+      KSpread::Range p( point.translation );
 
-      kdDebug(30518) << "Print table: " << p.sheetName << endl;
+      kdDebug(30518) << "Print table: " << p.sheetName() << endl;
 
-      if ( table->sheetName() == p.sheetName )
-        table->print()->setPrintRange( p.range );
+      if ( table->sheetName() == p.sheetName() )
+        table->print()->setPrintRange( p.range() );
     }
 
     if ( !readColLayouts( t, table ) )
@@ -1629,7 +1625,7 @@ void OpenCalcImport::loadOasisAreaName( const QDomElement&body )
 
       if ( point.translation.find( ':' ) == -1 )
       {
-        KSpreadPoint p( point.translation );
+        Point p( point.translation );
 
         int n = range.find( '!' );
         if ( n > 0 )
@@ -1638,10 +1634,10 @@ void OpenCalcImport::loadOasisAreaName( const QDomElement&body )
         kdDebug(30518) << "=> Area: " << range << endl;
       }
 
-      KSpreadRange p( range );
+      KSpread::Range p( range );
 
-      m_doc->addAreaName( p.range, name, p.sheetName );
-      kdDebug(30518) << "Area range: " << p.sheetName << endl;
+      m_doc->addAreaName( p.range(), name, p.sheetName() );
+      kdDebug(30518) << "Area range: " << p.sheetName() << endl;
     }
   }
 }
@@ -1965,7 +1961,7 @@ QString * OpenCalcImport::loadFormat( QDomElement * element,
   return format;
 }
 
-void OpenCalcImport::loadFontStyle( KSpreadFormat * layout, QDomElement const * font ) const
+void OpenCalcImport::loadFontStyle( Format * layout, QDomElement const * font ) const
 {
   if ( !font || !layout )
     return;
@@ -1977,7 +1973,7 @@ void OpenCalcImport::loadFontStyle( KSpreadFormat * layout, QDomElement const *
   if ( font->hasAttributeNS( ooNS::fo, "color" ) )
     layout->setTextColor( QColor( font->attributeNS( ooNS::fo, "color", QString::null ) ) );
   if ( font->hasAttributeNS( ooNS::fo, "font-size" ) )
-      layout->setTextFontSize( KoUnit::parseValue( font->attributeNS( ooNS::fo, "font-size", QString::null ), 10 ) );
+      layout->setTextFontSize( int( KoUnit::parseValue( font->attributeNS( ooNS::fo, "font-size", QString::null ), 10 ) ) );
   else
     layout->setTextFontSize( 10 );
   if ( font->hasAttributeNS( ooNS::fo, "font-style" ) )
@@ -1999,7 +1995,7 @@ void OpenCalcImport::loadFontStyle( KSpreadFormat * layout, QDomElement const *
   // text-underline-color
 }
 
-void OpenCalcImport::loadBorder( KSpreadFormat * layout, QString const & borderDef, bPos pos ) const
+void OpenCalcImport::loadBorder( Format * layout, QString const & borderDef, bPos pos ) const
 {
   if ( borderDef == "none" )
     return;
@@ -2058,7 +2054,7 @@ void OpenCalcImport::loadBorder( KSpreadFormat * layout, QString const & borderD
   // TODO Diagonals not supported by oocalc
 }
 
-void OpenCalcImport::loadStyleProperties( KSpreadFormat * layout, QDomElement const & property ) const
+void OpenCalcImport::loadStyleProperties( Format * layout, QDomElement const & property ) const
 {
   kdDebug(30518) << "*** Loading style properties *****" << endl;
 
@@ -2104,13 +2100,13 @@ void OpenCalcImport::loadStyleProperties( KSpreadFormat * layout, QDomElement co
   {
     QString s = property.attributeNS( ooNS::fo, "text-align", QString::null );
     if ( s == "center" )
-      layout->setAlign( KSpreadFormat::Center );
+      layout->setAlign( Format::Center );
     else if ( s == "end" )
-      layout->setAlign( KSpreadFormat::Right );
+      layout->setAlign( Format::Right );
     else if ( s == "start" )
-      layout->setAlign( KSpreadFormat::Left );
+      layout->setAlign( Format::Left );
     else if ( s == "justify" ) // TODO in KSpread!
-      layout->setAlign( KSpreadFormat::Center );
+      layout->setAlign( Format::Center );
   }
   if (  property.hasAttributeNS( ooNS::fo, "margin-left" ) )
   {
@@ -2168,14 +2164,14 @@ void OpenCalcImport::loadStyleProperties( KSpreadFormat * layout, QDomElement co
   {
     QString s = property.attributeNS( ooNS::fo, "vertical-align", QString::null );
     if ( s == "middle" )
-      layout->setAlignY( KSpreadFormat::Middle );
+      layout->setAlignY( Format::Middle );
     else if ( s == "bottom" )
-      layout->setAlignY( KSpreadFormat::Bottom );
+      layout->setAlignY( Format::Bottom );
     else
-      layout->setAlignY( KSpreadFormat::Top );
+      layout->setAlignY( Format::Top );
   }
   else
-      layout->setAlignY( KSpreadFormat::Bottom );
+      layout->setAlignY( Format::Bottom );
 
   if ( property.hasAttributeNS( ooNS::fo, "wrap-option" ) )
   {
@@ -2219,14 +2215,14 @@ void OpenCalcImport::loadStyleProperties( KSpreadFormat * layout, QDomElement co
   }
 }
 
-void OpenCalcImport::readInStyle( KSpreadFormat * layout, QDomElement const & style )
+void OpenCalcImport::readInStyle( Format * layout, QDomElement const & style )
 {
   kdDebug(30518) << "** Reading Style: " << style.tagName() << "; " << style.attributeNS( ooNS::style, "name", QString::null) << endl;
   if ( style.localName() == "style" && style.namespaceURI()==ooNS::style)
   {
     if ( style.hasAttributeNS( ooNS::style, "parent-style-name" ) )
     {
-      KSpreadFormat * cp
+      Format * cp
         = m_defaultStyles.find( style.attributeNS( ooNS::style, "parent-style-name", QString::null ) );
       kdDebug(30518) << "Copying layout from " << style.attributeNS( ooNS::style, "parent-style-name", QString::null ) << endl;
 
@@ -2236,7 +2232,7 @@ void OpenCalcImport::readInStyle( KSpreadFormat * layout, QDomElement const & st
     else if ( style.hasAttributeNS( ooNS::style, "family") )
     {
       QString name = style.attribute( "style-family" ) + "default";
-      KSpreadFormat * cp = m_defaultStyles.find( name );
+      Format * cp = m_defaultStyles.find( name );
 
       kdDebug(30518) << "Copying layout from " << name << ", " << !cp << endl;
 
@@ -2361,7 +2357,7 @@ bool OpenCalcImport::createStyleMap( QDomDocument const & styles )
 
     if ( !e.isNull() )
     {
-      KSpreadFormat * layout = new KSpreadFormat( 0, m_doc->styleManager()->defaultStyle() );
+      Format * layout = new Format( 0, m_doc->styleManager()->defaultStyle() );
 
       readInStyle( layout, e );
       kdDebug(30518) << "Default style " << e.attributeNS( ooNS::style, "family", QString::null ) << "default" << " loaded " << endl;
@@ -2387,7 +2383,7 @@ bool OpenCalcImport::createStyleMap( QDomDocument const & styles )
       continue;
     }
 
-    KSpreadFormat * layout = new KSpreadFormat( 0, m_doc->styleManager()->defaultStyle() );
+    Format * layout = new Format( 0, m_doc->styleManager()->defaultStyle() );
     readInStyle( layout, defs );
     kdDebug(30518) << "Default style " << defs.attributeNS( ooNS::style, "name", QString::null ) << " loaded " << endl;
 
@@ -2422,7 +2418,7 @@ bool OpenCalcImport::createStyleMap( QDomDocument const & styles )
   return true;
 }
 
-void OpenCalcImport::loadOasisValidation( KSpreadValidity* val, const QString& validationName )
+void OpenCalcImport::loadOasisValidation( Validity* val, const QString& validationName )
 {
     kdDebug(30518)<<"validationName:"<<validationName<<endl;
     QDomElement element = m_validationList[validationName];
@@ -2448,15 +2444,15 @@ void OpenCalcImport::loadOasisValidation( KSpreadValidity* val, const QString& v
             //"cell-content-text-length()>45"
             valExpression = valExpression.remove("cell-content-text-length()" );
             kdDebug(30518)<<" valExpression = :"<<valExpression<<endl;
-            val->m_allow = Allow_TextLength;
+            val->m_restriction = Restriction::TextLength;
 
             loadOasisValidationCondition( val, valExpression );
         }
         //cell-content-text-length-is-between(Value, Value) | cell-content-text-length-is-not-between(Value, Value)
         else if ( valExpression.contains( "cell-content-text-length-is-between" ) )
         {
-            val->m_allow = Allow_TextLength;
-            val->m_cond = Between;
+            val->m_restriction = Restriction::TextLength;
+            val->m_cond = Conditional::Between;
             valExpression = valExpression.remove( "cell-content-text-length-is-between(" );
             kdDebug(30518)<<" valExpression :"<<valExpression<<endl;
             valExpression = valExpression.remove( ")" );
@@ -2465,8 +2461,8 @@ void OpenCalcImport::loadOasisValidation( KSpreadValidity* val, const QString& v
         }
         else if ( valExpression.contains( "cell-content-text-length-is-not-between" ) )
         {
-            val->m_allow = Allow_TextLength;
-            val->m_cond = Different;
+            val->m_restriction = Restriction::TextLength;
+            val->m_cond = Conditional::Different;
             valExpression = valExpression.remove( "cell-content-text-length-is-not-between(" );
             kdDebug(30518)<<" valExpression :"<<valExpression<<endl;
             valExpression = valExpression.remove( ")" );
@@ -2480,22 +2476,22 @@ void OpenCalcImport::loadOasisValidation( KSpreadValidity* val, const QString& v
         {
             if (valExpression.contains( "cell-content-is-whole-number()" ) )
             {
-                val->m_allow =  Allow_Number;
+                val->m_restriction =  Restriction::Number;
                 valExpression = valExpression.remove( "cell-content-is-whole-number() and " );
             }
             else if (valExpression.contains( "cell-content-is-decimal-number()" ) )
             {
-                val->m_allow = Allow_Integer;
+                val->m_restriction = Restriction::Integer;
                 valExpression = valExpression.remove( "cell-content-is-decimal-number() and " );
             }
             else if (valExpression.contains( "cell-content-is-date()" ) )
             {
-                val->m_allow = Allow_Date;
+                val->m_restriction = Restriction::Date;
                 valExpression = valExpression.remove( "cell-content-is-date() and " );
             }
             else if (valExpression.contains( "cell-content-is-time()" ) )
             {
-                val->m_allow = Allow_Time;
+                val->m_restriction = Restriction::Time;
                 valExpression = valExpression.remove( "cell-content-is-time() and " );
             }
             kdDebug(30518)<<"valExpression :"<<valExpression<<endl;
@@ -2514,7 +2510,7 @@ void OpenCalcImport::loadOasisValidation( KSpreadValidity* val, const QString& v
                 QStringList listVal = QStringList::split( "," , valExpression );
                 loadOasisValidationValue( val, listVal );
 
-                val->m_cond = Between;
+                val->m_cond = Conditional::Between;
             }
             if ( valExpression.contains( "cell-content-is-not-between(" ) )
             {
@@ -2522,7 +2518,7 @@ void OpenCalcImport::loadOasisValidation( KSpreadValidity* val, const QString& v
                 valExpression = valExpression.remove( ")" );
                 QStringList listVal = QStringList::split( ",", valExpression );
                 loadOasisValidationValue( val, listVal );
-                val->m_cond = Different;
+                val->m_cond = Conditional::Different;
             }
         }
     }
@@ -2557,11 +2553,11 @@ void OpenCalcImport::loadOasisValidation( KSpreadValidity* val, const QString& v
         {
             QString str = error.attributeNS( ooNS::table, "message-type", QString::null );
             if ( str == "warning" )
-                val->m_action = Warning;
+              val->m_action = Action::Warning;
             else if ( str == "information" )
-                val->m_action = Information;
+              val->m_action = Action::Information;
             else if ( str == "stop" )
-                val->m_action = Stop;
+              val->m_action = Action::Stop;
             else
                 kdDebug(30518)<<"validation : message type unknown  :"<<str<<endl;
         }
@@ -2577,17 +2573,17 @@ void OpenCalcImport::loadOasisValidation( KSpreadValidity* val, const QString& v
     }
 }
 
-void OpenCalcImport::loadOasisValidationValue( KSpreadValidity* val, const QStringList &listVal )
+void OpenCalcImport::loadOasisValidationValue( Validity* val, const QStringList &listVal )
 {
     bool ok = false;
     kdDebug(30518)<<" listVal[0] :"<<listVal[0]<<" listVal[1] :"<<listVal[1]<<endl;
 
-    if ( val->m_allow == Allow_Date )
+    if ( val->m_restriction == Restriction::Date )
     {
         val->dateMin = QDate::fromString( listVal[0] );
         val->dateMax = QDate::fromString( listVal[1] );
     }
-    else if ( val->m_allow == Allow_Time )
+    else if ( val->m_restriction == Restriction::Time )
     {
         val->timeMin = QTime::fromString( listVal[0] );
         val->timeMax = QTime::fromString( listVal[1] );
@@ -2623,48 +2619,48 @@ void OpenCalcImport::loadOasisValidationValue( KSpreadValidity* val, const QStri
 }
 
 
-void OpenCalcImport::loadOasisValidationCondition( KSpreadValidity* val,QString &valExpression )
+void OpenCalcImport::loadOasisValidationCondition( Validity* val,QString &valExpression )
 {
     QString value;
     if (valExpression.contains( "<=" ) )
     {
         value = valExpression.remove( "<=" );
-        val->m_cond = InferiorEqual;
+        val->m_cond = Conditional::InferiorEqual;
     }
     else if (valExpression.contains( ">=" ) )
     {
         value = valExpression.remove( ">=" );
-        val->m_cond = SuperiorEqual;
+        val->m_cond = Conditional::SuperiorEqual;
     }
     else if (valExpression.contains( "!=" ) )
     {
         //add Differentto attribute
         value = valExpression.remove( "!=" );
-        val->m_cond = DifferentTo;
+        val->m_cond = Conditional::DifferentTo;
     }
     else if ( valExpression.contains( "<" ) )
     {
         value = valExpression.remove( "<" );
-        val->m_cond = Inferior;
+        val->m_cond = Conditional::Inferior;
     }
     else if(valExpression.contains( ">" ) )
     {
         value = valExpression.remove( ">" );
-        val->m_cond = Superior;
+        val->m_cond = Conditional::Superior;
     }
     else if (valExpression.contains( "=" ) )
     {
         value = valExpression.remove( "=" );
-        val->m_cond = Equal;
+        val->m_cond = Conditional::Equal;
     }
     else
         kdDebug(30518)<<" I don't know how to parse it :"<<valExpression<<endl;
     kdDebug(30518)<<" value :"<<value<<endl;
-    if ( val->m_allow == Allow_Date )
+    if ( val->m_restriction == Restriction::Date )
     {
         val->dateMin = QDate::fromString( value );
     }
-    else if ( val->m_allow == Allow_Date )
+    else if ( val->m_restriction == Restriction::Date )
     {
         val->timeMin = QTime::fromString( value );
     }
@@ -2746,9 +2742,9 @@ KoFilter::ConversionStatus OpenCalcImport::convert( QCString const & from, QCStr
   if ( !document )
     return KoFilter::StupidError;
 
-  if ( strcmp(document->className(), "KSpreadDoc") != 0 )  // it's safer that way :)
+  if (  !::qt_cast<const KSpread::Doc *>( document ) )  // it's safer that way :)
   {
-    kdWarning(30518) << "document isn't a KSpreadDoc but a " << document->className() << endl;
+    kdWarning(30518) << "document isn't a KSpread::Doc but a " << document->className() << endl;
     return KoFilter::NotImplemented;
   }
 
@@ -2758,7 +2754,7 @@ KoFilter::ConversionStatus OpenCalcImport::convert( QCString const & from, QCStr
     return KoFilter::NotImplemented;
   }
 
-  m_doc = ( KSpreadDoc * ) document;
+  m_doc = ( Doc * ) document;
 
   if ( m_doc->mimeType() != "application/x-kspread" )
   {
