@@ -1,5 +1,3 @@
-//
-
 /*
    This file is part of the KDE project
    Copuright (C) 2001 Michael Johnson <mikej@xnet.com>
@@ -18,8 +16,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <qstring.h>
@@ -172,7 +170,8 @@ QString RTFWorker::makeTable(const FrameAnchor& anchor)
         QString endOfParagraph;
         QValueList<ParaData> *paraList = (*itCell).paraList;
         QValueList<ParaData>::ConstIterator it;
-        for (it=paraList->begin();it!=paraList->end();it++)
+		QValueList<ParaData>::ConstIterator end(paraList->end());
+        for (it=paraList->begin();it!=end;++it)
         {
             rowText += endOfParagraph;
             rowText += ProcessParagraphData( (*it).text,(*it).layout,(*it).formattingList);
@@ -725,7 +724,8 @@ if (layout.counter.style)
                     {
                         QString fstr;
                         QValueList<ParaData>::ConstIterator it;
-                        for (it=paraList->begin();it!=paraList->end();it++)
+						QValueList<ParaData>::ConstIterator end(paraList->end());
+                        for (it=paraList->begin();it!=end;++it)
                             fstr += ProcessParagraphData( (*it).text, (*it).layout,(*it).formattingList);
                         content += "{\\super ";
                         content += automatic ? "\\chftn " : value;
@@ -833,7 +833,8 @@ bool RTFWorker::doHeader(const HeaderData& header)
     str += " {";
 
     QValueList<ParaData>::ConstIterator it;
-    for (it=header.para.begin();it!=header.para.end();it++)
+	QValueList<ParaData>::ConstIterator end(header.para.end());
+    for (it=header.para.begin();it!=end;++it)
         content += ProcessParagraphData( (*it).text,(*it).layout,(*it).formattingList);
 
     if (content!="\\par\\pard\\plain")
@@ -867,7 +868,8 @@ bool RTFWorker::doFooter(const FooterData& footer)
     str += " {";
 
     QValueList<ParaData>::ConstIterator it;
-    for (it=footer.para.begin();it!=footer.para.end();it++)
+	QValueList<ParaData>::ConstIterator end(footer.para.end());
+    for (it=footer.para.begin();it!=end;++it)
         content += ProcessParagraphData( (*it).text,(*it).layout,(*it).formattingList);
 
     if (content!="\\par\\pard\\plain")
@@ -1038,7 +1040,7 @@ void RTFWorker::writeStyleData(void)
         // Find the number of the following style
         uint counter=0;  // counts position in style table starting at 0
         QValueList < LayoutData > ::ConstIterator it2;
-        for( it2 =  m_styleList.begin(); it2 != m_styleList.end(); counter++, it2++ )
+        for( it2 =  m_styleList.begin(); it2 != m_styleList.end(); counter++, ++it2 )
         {
             if ( (*it2).styleName == (*it).styleFollowing )
             {
@@ -1126,7 +1128,7 @@ bool RTFWorker::doFullDocumentInfo(const KWEFDocumentInfo& docInfo)
     }
 
     // Now add who we are in a \comment
-    QString revision("$Revision: 388763 $");
+    QString revision("$Revision: 466447 $");
     m_textDocInfo += "{\\comment ";
     m_textDocInfo += "Generated by KWord's RTF Export Filter";
     m_textDocInfo += revision.mid(10).remove('$'); // has a leading and a trailing space.
@@ -1570,7 +1572,7 @@ QString RTFWorker::layoutToRtf(const LayoutData& layoutOrigin,
         && (force || (layoutOrigin.tabulatorList!=layout.tabulatorList) ))
     {
         TabulatorList::ConstIterator it;
-        for (it=layout.tabulatorList.begin();it!=layout.tabulatorList.end();it++)
+        for (it=layout.tabulatorList.begin();it!=layout.tabulatorList.end();++it)
         {
             switch ((*it).m_type)
             {
@@ -1638,7 +1640,7 @@ QString RTFWorker::lookupFont(const QString& markup, const QString& fontName)
     QStringList::ConstIterator it;
 
     // search font table for this font
-    for( it = m_fontList.begin(); it != m_fontList.end(); counter++, it++ )
+    for( it = m_fontList.begin(); it != m_fontList.end(); counter++, ++it )
     {
         if((*it) == cookedFontName)  // check for match
         {
@@ -1666,7 +1668,7 @@ QString RTFWorker::lookupColor(const QString& markup, const QColor& color)
     QValueList < QColor > ::ConstIterator it;
 
     // search color table for this color
-    for( it =  m_colorList.begin(); it != m_colorList.end(); counter++, it++ )
+    for( it =  m_colorList.begin(); it != m_colorList.end(); counter++, ++it )
     {
         if ( (*it) == color )
         {
@@ -1691,9 +1693,10 @@ QString RTFWorker::lookupStyle(const QString& styleName, LayoutData& returnLayou
     QString strMarkup("\\s");  // Holds RTF markup for the style
 
     QValueList < LayoutData > ::ConstIterator it;
+	QValueList < LayoutData > ::ConstIterator end(m_styleList.end());
 
     // search color table for this color
-    for( it =  m_styleList.begin(); it != m_styleList.end(); counter++, it++ )
+    for( it =  m_styleList.begin(); it != end; counter++, ++it )
     {
         if ( (*it).styleName == styleName )
         {
