@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include "xsltimportdia.h"
@@ -23,6 +23,7 @@
 //#include <stdio.h>
 
 #include <qcombobox.h>
+#include <qcursor.h>
 #include <qstringlist.h>
 #include <qdir.h>
 
@@ -31,7 +32,7 @@
 #include <kstandarddirs.h>
 #include <kglobal.h>
 #include <krecentdocument.h>
-#include <koFilterManager.h>
+#include <KoFilterManager.h>
 #include <ktempfile.h>
 #include <kdebug.h>
 
@@ -101,6 +102,7 @@ XSLTImportDia::XSLTImportDia(KoStore* out, const QCString &format, QWidget* pare
 	}
 	
 	xsltList->insertStringList(_namesList);
+	kapp->restoreOverrideCursor();
 }
 
 /*
@@ -198,6 +200,7 @@ void XSLTImportDia::chooseCommonSlot()
  */
 void XSLTImportDia::okSlot()
 {
+  	kapp->setOverrideCursor(QCursor(Qt::WaitCursor));
 	hide();
 	if(_currentFile.url().isEmpty())
 		return;
