@@ -13,15 +13,15 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __VPATH_H__
 #define __VPATH_H__
 
 
-#include <koPoint.h>
+#include <KoPoint.h>
 
 #include "vobject.h"
 #include <koffice_export.h>
@@ -106,8 +106,8 @@ public:
 	virtual const KoRect& boundingBox() const;
 
 
-	virtual void save( QDomElement& ) const
-		{}	// VSubpaths cant be saved.
+	virtual void save( QDomElement& /*element*/) const
+		{ }	// VSubpaths cant be saved.
 
 	// TODO: remove this backward compatibility function after koffice 1.3.x
 	virtual void load( const QDomElement& element );
