@@ -1,3 +1,4 @@
+#include <qcheckbox.h>
 #include <qlabel.h>
 #include <qspinbox.h>
 #include <qlayout.h>
@@ -6,6 +7,7 @@
 #include <qwhatsthis.h>
 #include <qtooltip.h>
 #include <qvalidator.h>
+#include <qpushbutton.h>
 
 #include <kinputdialog.h>
 #include <klocale.h>
@@ -102,6 +104,7 @@ kchartDataTable::~kchartDataTable()
 {
 }
 
+
 bool kchartDataTable::eventFilter( QObject *obj, QEvent *ev )
 {
     if (ev->type() == QEvent::KeyPress && strcmp(obj->name(), 
@@ -118,7 +121,8 @@ bool kchartDataTable::eventFilter( QObject *obj, QEvent *ev )
                 }
                 break;
             }
-            case Qt::Key_Down: {
+            case Qt::Key_Down: 
+	    {
                 if ( currentRow() < numRows()-1 ) {
                     setCurrentCell( currentRow()+1, currentColumn() );
                     editCell(currentRow(), currentColumn() );
@@ -126,7 +130,8 @@ bool kchartDataTable::eventFilter( QObject *obj, QEvent *ev )
                 }
                 break;
             }
-            case Qt::Key_Right: {
+            case Qt::Key_Right: 
+	    {
                 if ( currentColumn() < numCols()-1 ) {
                     setCurrentCell( currentRow(), currentColumn()+1 );
                     editCell(currentRow(), currentColumn() );
@@ -145,6 +150,7 @@ bool kchartDataTable::eventFilter( QObject *obj, QEvent *ev )
             }
         }
     }
+
     return QTable::eventFilter( obj, ev );
 }
 
@@ -157,18 +163,18 @@ bool kchartDataTable::eventFilter( QObject *obj, QEvent *ev )
 
 kchartDataEditor::kchartDataEditor(QWidget* parent) :
     KDialogBase(parent, "dataeditor", true, i18n("KChart Data Editor"), 
-		KDialogBase::Ok|KDialogBase::Cancel|KDialogBase::Apply,
+		KDialogBase::Ok | KDialogBase::Cancel | KDialogBase::Apply,
 		KDialogBase::Ok, true)
 {
-    //setCaption(i18n("KChart Data Editor"));
-
     QWidget      *page = new QWidget( this );
     setMainWidget(page);
 
     // Create the main table.
     m_table = new kchartDataTable(page);
     m_table->setSelectionMode(QTable::NoSelection);
-	m_table->setFocus();
+    m_table->setFocus();
+    m_table->setRowMovingEnabled(true);
+    m_table->setColumnMovingEnabled(true);
 
     // Create the Rows setting
     m_rowsLA = new QLabel( i18n("# Rows:" ), page );
@@ -183,22 +189,70 @@ kchartDataEditor::kchartDataEditor(QWidget* parent) :
     m_colsSB = new kchartDataSpinBox( page );
     m_colsSB->resize( m_colsSB->sizeHint() );
     m_colsSB->setMinValue(1);
-
-    // Start the layout.  The table is at the top.
+    
+#if 0
+    // The row/column as label checkboxes. 
+    m_firstRowAsLabel = new QCheckBox( i18n( "First row as label" ), page);
+    m_firstColAsLabel = new QCheckBox( i18n( "First column as label" ), page);
+#endif
+    //Buttons for Inserting / Removing rows & columns 
+    QPushButton *insertRowButton = new QPushButton( i18n("Insert Row") , page);
+    connect( insertRowButton, SIGNAL( clicked() ),
+	     this,            SLOT( insertRow() ) );
+    
+    QPushButton *insertColButton = new QPushButton( i18n("Insert Column") , page);
+    connect( insertColButton, SIGNAL( clicked() ),
+	     this,            SLOT( insertColumn() ) );
+    
+    QPushButton* removeRowButton = new QPushButton( i18n("Remove Row") , page);
+    connect( removeRowButton, SIGNAL( clicked() ),
+	     this,            SLOT( removeCurrentRow() ) );
+    
+    QPushButton* removeColButton = new QPushButton( i18n("Remove Column") , page);
+    connect( removeColButton, SIGNAL( clicked() ),
+	     this,            SLOT( removeCurrentColumn() ) );
+        
+  
+    // Start the layout.  The buttons are at the top.
     QVBoxLayout  *topLayout = new QVBoxLayout( page );
+    
+    QHBoxLayout* insertRemoveLayout = new QHBoxLayout( );
+   
+    insertRemoveLayout->setSpacing(5);
+    insertRemoveLayout->addWidget(insertRowButton);
+    insertRemoveLayout->addWidget(insertColButton);
+    insertRemoveLayout->addWidget(removeRowButton);
+    insertRemoveLayout->addWidget(removeColButton);
+    insertRemoveLayout->addStretch(1);
+    
+    topLayout->addLayout(insertRemoveLayout);
+    topLayout->addSpacing(10);
+    
+    // The table is below the buttons.
     topLayout->addWidget(m_table);
 
     // Then, a horizontal layer with the rows and columns settings
-    QHBoxLayout  *rowColLayout = new QHBoxLayout(  );
-    rowColLayout->addWidget(m_rowsLA);
-    rowColLayout->addWidget(m_rowsSB);
-    rowColLayout->addWidget(m_colsLA);
-    rowColLayout->addWidget(m_colsSB);
-    rowColLayout->addStretch(1);
-    rowColLayout->setMargin(10);
+    QHBoxLayout  *hbl1 = new QHBoxLayout(  );
+    hbl1->addWidget(m_rowsLA);
+    hbl1->addWidget(m_rowsSB);
+    hbl1->addSpacing(20);
+    hbl1->addWidget(m_colsLA);
+    hbl1->addWidget(m_colsSB);
+    hbl1->addStretch(1);
+    hbl1->setMargin(10);
+    topLayout->addLayout(hbl1);
+
+#if 0
+    QHBoxLayout  *hbl2 = new QHBoxLayout(  );
+    hbl2->addWidget(m_firstRowAsLabel);
+    hbl2->addWidget(m_firstColAsLabel);
+    hbl2->addStretch(1);
+    hbl2->setMargin(10);
+    topLayout->addLayout(hbl2);
+#endif
 
-    topLayout->addLayout(rowColLayout);
     topLayout->setStretchFactor(m_table, 1);
+    topLayout->setStretchFactor(insertRemoveLayout,1);
 
     // Connect signals from the spin boxes.
     connect(m_rowsSB, SIGNAL(valueChangedSpecial(int)), 
@@ -206,11 +260,18 @@ kchartDataEditor::kchartDataEditor(QWidget* parent) :
     connect(m_colsSB, SIGNAL(valueChangedSpecial(int)), 
 	    this,     SLOT(setCols(int)));
 
+
+    
+#if 0
+    // -- Changed data editor to use top row and leftmost column for
+    //    series names and labels so this is no longer necessary.
+
     connect(m_table->horizontalHeader(), SIGNAL(clicked(int)), 
 	    this,                        SLOT(column_clicked(int)) );
     connect(m_table->verticalHeader(),   SIGNAL(clicked(int)),
 	    this,                        SLOT(row_clicked(int)) );
-
+#endif
+  
     connect(m_table, SIGNAL(valueChanged(int, int)),
 	    this,    SLOT(tableChanged(int, int)) );
 
@@ -246,9 +307,29 @@ void kchartDataEditor::addDocs()
     QWhatsThis::add(m_colsSB, colwhatsthis);
 
     // The table.
-    QToolTip::add(m_table, i18n("Chart data, each row is a data set. "
-			       "Headers can be changed by clicking on them."));
-    QWhatsThis::add(m_table, i18n("<p>This table represents the complete data"
+    QToolTip::add(m_table, i18n("Chart data table."));
+    
+    //GUI
+    //The QWhatsThis information below is incorrect since the way that the contents of the table
+    //are displayed in the chart depends upon the data format selected (which can be 
+    //either "Data in columns" (default) or "Data in rows)
+    //The names of the data sets / axes labels are no longer set by clicking on the table 
+    //headers - since that was slow to work with and did not allow for keyboard input. 
+    //Instead the names are taken from the topmost row and leftmost column.  
+    //
+    //eg:       Month | Sales 
+    //          Jan   | 105
+    //          Feb   | 117
+    //          March | 120
+    //
+    //The captions of the header are automatically set to the names of the cells in the topmost row
+    //and leftmost column.  This means that if you have more data than will fit in the visible area,
+    //you can still see the column names or row names when the table has been scrolled.
+    //KSpread could use some functionality like this as well.
+    
+    
+#if 0
+    QWhatsThis::add(m_table, i18n("<p>This table contains the data"
     " for the chart.<br><br> Each row is one data set of values."
     " The name of such a data set can be changed in the column header (on the left)"
     " of the table. In a line diagram each row is one line. In a ring diagram each row"
@@ -257,6 +338,7 @@ void kchartDataEditor::addDocs()
     " column headers (at the top) of the table.  In a bar diagram the number"
     " of columns defines the number of value sets.  In a ring diagram each"
     " column is one ring.</p>"));
+#endif
 }
 
 
@@ -265,7 +347,7 @@ void kchartDataEditor::addDocs()
 // The data is taken from the KDChart data.  This method is never
 // called when the chart is a part of a spreadsheet.
 //
-void kchartDataEditor::setData( KoChart::Data* dat )
+void kchartDataEditor::setData( KChartParams *params, KDChartTableData *dat )
 {
     unsigned int  rowsCount;
     unsigned int  colsCount;
@@ -288,28 +370,37 @@ void kchartDataEditor::setData( KoChart::Data* dat )
 	return;
     }
 
+    rowsCount += headerRows();
+    colsCount += headerCols();
+
     // Initiate widgets with the correct rows and columns.
     m_rowsSB->setValue(rowsCount);
     m_colsSB->setValue(colsCount);
+#if 0
+    m_firstRowAsLabel->setChecked( params->firstRowAsLabel() );
+    m_firstColAsLabel->setChecked( params->firstColAsLabel() );
+#endif
     m_table->setNumRows(rowsCount);
     m_table->setNumCols(colsCount);
 
     // Fill the data from the chart into the editor.
-    for (unsigned int row = 0; row < rowsCount; row++) {
-        for (unsigned int col = 0; col < colsCount; col++) {
-            KoChart::Value t = dat->cell(row, col);
+    for (unsigned int row = headerRows(); row < rowsCount; row++) {
+        for (unsigned int col = headerCols(); col < colsCount; col++) {
+            QVariant t = dat->cellVal(row-headerRows(), col-headerCols());
+
 
             // Fill it in from the part.
-            if (t.hasValue()) {
-                if ( t.isDouble() ) {
+            if (t.isValid()) {
+                if ( t.type() == QVariant::Double ) {
 		    m_table->setText(row, col, 
-				     QString("%1").arg(t.doubleValue()));
+				     QString("%1").arg(t.toDouble()));
 		}
-                else if ( t.isString() )
+                else if ( t.type() == QVariant::String )
                     kdDebug(35001) << "I cannot handle strings in the table yet"
                                    << endl;
-                else
-                    ; // nothing on purpose
+                else {
+                    // nothing on purpose
+                }
             }
         }
     }
@@ -325,11 +416,16 @@ void kchartDataEditor::setData( KoChart::Data* dat )
 
 // Get the data from the data editor and put it back into the chart.
 //
-void kchartDataEditor::getData( KoChart::Data* dat )
-{
-    int  numRows = m_rowsSB->value();
-    int  numCols = m_colsSB->value();
-
+void kchartDataEditor::getData( KChartParams *params, KDChartTableData *dat )
+{	
+    //Number of rows used as headers
+    int labelRows = headerRows();
+    //Number of columns used as headers	
+    int labelCols = headerCols();
+    
+    int  numRows = m_table->numRows()-labelRows;
+    int  numCols = m_table->numCols()-labelCols;
+	
     // Make sure that the data table for the chart is not smaller than
     // the data in the editor.
     if ( static_cast<int>( dat->rows() ) < numRows
@@ -340,30 +436,35 @@ void kchartDataEditor::getData( KoChart::Data* dat )
     dat->setUsedCols( numCols );
 
 	// Empty table
+#if 0
 	if ( numRows==1 && numCols==1 && m_table->horizontalHeader()->label(0).isEmpty()
 			&& m_table->verticalHeader()->label(0).isEmpty()
 			&& m_table->text(0, 0).isEmpty() ) {
 		dat->expand(0,0);
 		return;
 	}
+#endif
 
     // Get all the data.
-    for (int row = 0;row < numRows; row++) {
-        for (int col = 0;col < numCols; col++) {
-            KoChart::Value t;
+    for (int row = labelRows ; row < (numRows+labelRows); row++) {
+        for (int col = labelCols ; col < (numCols+labelCols); col++) {
 
-	    // Get the text and convert to double.
-	    QString tmp = m_table->text(row, col);
-	    bool    ok;
-	    double  val = tmp.toDouble(&ok);
-	    if (!ok)
-		val = 0.0;
-
-	    // and do the actual setting.
-	    t = KoChart::Value( val );
-            dat->setCell(row,col,t);
+            // Get the text and convert to double.
+            QString tmp = m_table->text(row, col);
+            bool   bOk;
+            double val = tmp.toDouble( &bOk );
+            if (!bOk)
+              val = 0.0;
+            // and do the actual setting.
+            //t = KoChart::Value( val );
+            dat->setCell(row-labelRows,col-labelCols, val);
         }
     }
+
+#if 0
+    params->setFirstRowAsLabel( m_firstRowAsLabel->isChecked() );
+    params->setFirstColAsLabel( m_firstColAsLabel->isChecked() );
+#endif
 }
 
 
@@ -371,6 +472,7 @@ void kchartDataEditor::getData( KoChart::Data* dat )
 //
 void kchartDataEditor::setRowLabels(const QStringList &rowLabels)
 {
+#if 0
     QHeader  *rowHeader = m_table->verticalHeader();
     int       row;
     int       numRows = m_rowsSB->value();
@@ -381,6 +483,24 @@ void kchartDataEditor::setRowLabels(const QStringList &rowLabels)
     for (row = 0; row < numRows; row++) {
 	rowHeader->setLabel(row, rowLabels[row]);
     }
+#endif
+
+    for (unsigned int i=0; i < rowLabels.count(); i++) {
+        m_table->setText(i + headerRows(), 0, rowLabels[i]);    
+    }
+    
+    updateRowHeaders();
+}
+
+
+int kchartDataEditor::headerRows()
+{
+    return 1;
+}
+
+int kchartDataEditor::headerCols()
+{
+    return 1;
 }
 
 
@@ -388,6 +508,7 @@ void kchartDataEditor::setRowLabels(const QStringList &rowLabels)
 //
 void kchartDataEditor::getRowLabels(QStringList &rowLabels)
 {
+#if 0
     QHeader  *rowHeader = m_table->verticalHeader();
     int  numRows = m_rowsSB->value();
     int  row;
@@ -396,6 +517,13 @@ void kchartDataEditor::getRowLabels(QStringList &rowLabels)
     for (row = 0; row < numRows; row++) {
       rowLabels << rowHeader->label(row);
     }
+#endif
+    rowLabels.clear();
+
+    for (int i=headerRows();i < m_table->numRows();i++)
+    {
+        rowLabels << m_table->text(i,0);
+    }
 }
 
 
@@ -403,6 +531,7 @@ void kchartDataEditor::getRowLabels(QStringList &rowLabels)
 //
 void kchartDataEditor::setColLabels(const QStringList &colLabels)
 {
+#if 0
     QHeader  *colHeader = m_table->horizontalHeader();
     int       col;
 
@@ -414,6 +543,14 @@ void kchartDataEditor::setColLabels(const QStringList &colLabels)
     for (col = 0; col < numCols; col++) {
 	colHeader->setLabel(col, colLabels[col]);
     }
+#endif
+
+    for (unsigned int i = 0; i < colLabels.count(); i++)
+    {
+        m_table->setText(0,i+headerCols(),colLabels[i]);
+    }
+    
+    updateColHeaders();
 }
 
 
@@ -421,13 +558,21 @@ void kchartDataEditor::setColLabels(const QStringList &colLabels)
 //
 void kchartDataEditor::getColLabels(QStringList &colLabels)
 {
+#if 0
     QHeader  *colHeader = m_table->horizontalHeader();
     int  numCols = m_colsSB->value();
     int  col;
 
     colLabels.clear();
     for (col = 0; col < numCols; col++) {
-      colLabels << colHeader->label(col);
+	colLabels << colHeader->label(col);
+    }
+#endif
+    
+    colLabels.clear();
+
+    for (int i = headerCols(); i < m_table->numCols(); i++) {
+        colLabels << m_table->text(0, i); 
     }
 }
 
@@ -436,10 +581,57 @@ void kchartDataEditor::getColLabels(QStringList &colLabels)
 //                              Slots
 
 
+// Slots for the buttons that insert/remove rows/columns.
+//
+
+void kchartDataEditor::removeCurrentRow()
+{
+    int  row = m_table->currentRow();
+    
+    m_table->removeRow(row);
+    m_rowsSB->setValue(m_table->numRows());
+    
+    if (row == 0)
+        updateColHeaders();   
+    
+    m_modified = true;
+}
+
+void kchartDataEditor::removeCurrentColumn()
+{
+    int  col = m_table->currentColumn();
+    
+    m_table->removeColumn(col);
+    m_colsSB->setValue(m_table->numCols());
+    
+    if (col == 0)
+        updateRowHeaders();
+    
+    m_modified = true;
+}
+
+void kchartDataEditor::insertColumn()
+{
+    m_table->insertColumns(m_table->currentColumn() + 1, 1);
+    m_colsSB->setValue(m_table->numCols());
+    updateColHeaders();
+
+    m_modified = true;
+}
+
+void kchartDataEditor::insertRow()
+{
+    m_table->insertRows(m_table->currentRow() + 1, 1);
+    m_rowsSB->setValue(m_table->numRows());
+    updateRowHeaders();
+
+    m_modified = true;
+}    
+
+
 // Ask user to make sure that (s)he really wants to remove a row or
 // column.
 //
-
 static int askUserForConfirmation(QWidget *parent)
 {
     return KMessageBox::warningContinueCancel(parent,
@@ -449,10 +641,7 @@ static int askUserForConfirmation(QWidget *parent)
 	     "This message will not be shown again if you click Continue"));
 }
 
-void kchartDataEditor::test()
-{
-  kdDebug() << "hej!" << endl;
-}
+
 // This slot is called when the spinbox for rows is changed.
 //
 void kchartDataEditor::setRows(int rows)
@@ -567,6 +756,7 @@ void kchartDataEditor::setCols(int cols)
 
 // Get the new name for a column header.
 //
+#if 0	// Disabled since the first row / column now contains the labels.
 void kchartDataEditor::column_clicked(int column)
 {
 	bool ok;
@@ -599,13 +789,49 @@ void kchartDataEditor::row_clicked(int row)
 	m_modified = true;
     }
 }
+#endif
 
 
-void  kchartDataEditor::tableChanged(int /*row*/, int /*col*/)
+void  kchartDataEditor::tableChanged(int row, int col)
 {
+    if (row <= headerRows())
+        updateColHeaders();
+    if (col <= headerCols())
+        updateRowHeaders();
+
     m_modified = true;
 }
 
+void kchartDataEditor::updateRowHeaders()
+{
+    for (int i=0;i<m_table->numRows();i++)
+    {
+        QHeader* header=m_table->verticalHeader();
+        
+        QString tableCellText=m_table->text(i,0);
+        
+        if (tableCellText == QString::null)
+            tableCellText=QString("");
+        
+        header->setLabel(header->mapToSection(i),tableCellText);
+    }
+}
+
+void kchartDataEditor::updateColHeaders()
+{
+    for (int i=0;i<m_table->numCols();i++)
+    {
+        QHeader* header=m_table->horizontalHeader();
+        
+        QString tableCellText=m_table->text(0,i);
+        
+        if (tableCellText == QString::null)
+            tableCellText=QString("");
+            
+        header->setLabel(header->mapToSection(i),tableCellText);
+    }
+}
+
 
 // This is a reimplementation of a slot defined in KDialogBase.  The
 // reason for the reimplementation is that we need to emit the signal
