@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <qworkspace.h>
@@ -44,13 +44,13 @@
 #include "container.h"
 #include "formmanager.h"
 #include "objecttreeview.h"
-#include "kexipropertyeditor.h"
+#include "koproperty/editor.h"
 
 #include "kfd_part.h"
 
 /*
-#define ENABLE_ACTION(name, enable) 
-	if(actionCollection()->action( name )) 
+#define ENABLE_ACTION(name, enable)
+	if(actionCollection()->action( name ))
 		actionCollection()->action( name )->setEnabled( enable )
 */
 
@@ -59,11 +59,10 @@ class KFDPart_FormManager : public KFormDesigner::FormManager
 	public:
 		/*! Constructs FormManager object.
 		 See WidgetLibrary's constructor documentation for information about
-		 \a supportedFactoryGroups parameter. 
+		 \a supportedFactoryGroups parameter.
 		 Using \a options you can control manager's behaviour, see \ref Options. */
-		KFDPart_FormManager(KFormDesignerPart *part, const QStringList& supportedFactoryGroups = QStringList(),
-			int options = 0, const char *name = 0)
-		 : KFormDesigner::FormManager(part, supportedFactoryGroups, options, name)
+		KFDPart_FormManager(KFormDesignerPart *part, int options = 0, const char *name = 0)
+		 : KFormDesigner::FormManager(part, options, name)
 		 , m_part(part)
 		{
 		}
@@ -74,7 +73,7 @@ class KFDPart_FormManager : public KFormDesigner::FormManager
 		}
 
 		virtual void enableAction( const char* name, bool enable ) {
-			if(m_part->actionCollection()->action( name )) 
+			if(m_part->actionCollection()->action( name ))
 				m_part->actionCollection()->action( name )->setEnabled( enable );
 		}
 
@@ -121,6 +120,8 @@ KFDFactory::aboutData()
 	return about;
 }
 
+KFormDesigner::WidgetLibrary* KFormDesignerPart::static_formsLibrary = 0L;
+
 KFormDesignerPart::KFormDesignerPart(QWidget *parent, const char *name, bool readOnly, const QStringList &args)
 : KParts::ReadWritePart(parent, name), m_count(0)
 {
@@ -141,9 +142,10 @@ KFormDesignerPart::KFormDesignerPart(QWidget *parent, const char *name, bool rea
 	m_workspace = new QWorkspace(container, "kfd_workspace");
 	m_workspace->show();
 
-/* @todo add configuration for supported factory groups */
 	QStringList supportedFactoryGroups;
-	m_manager = new KFDPart_FormManager(this, supportedFactoryGroups, 0, "kfd_manager");
+/* @todo add configuration for supported factory groups */
+	static_formsLibrary = KFormDesigner::FormManager::createWidgetLibrary( 
+		new KFDPart_FormManager(this, 0, "kfd_manager"), supportedFactoryGroups );
 
 	if(!readOnly)
 	{
@@ -157,12 +159,13 @@ KFormDesignerPart::KFormDesignerPart(QWidget *parent, const char *name, bool rea
 		dockTree->setFixedExtentWidth(256);
 
 		QDockWindow *dockEditor = new QDockWindow(dockArea);
-		KexiPropertyEditor *editor = new KexiPropertyEditor(dockEditor);
+		KoProperty::Editor *editor = new KoProperty::Editor(dockEditor);
 		dockEditor->setWidget(editor);
 		dockEditor->setCaption(i18n("Properties"));
 		dockEditor->setResizeEnabled(true);
 
-		m_manager->setEditors(editor, view);
+		KFormDesigner::FormManager::self()->setEditor(editor);
+		KFormDesigner::FormManager::self()->setObjectTreeView(view);
 
 		setupActions();
 		setModified(false);
@@ -171,22 +174,27 @@ KFormDesignerPart::KFormDesignerPart(QWidget *parent, const char *name, bool rea
 //		connect(m_manager, SIGNAL(widgetSelected(KFormDesigner::Form*, bool)), SLOT(slotWidgetSelected(KFormDesigner::Form*, bool)));
 //		connect(m_manager, SIGNAL(formWidgetSelected(KFormDesigner::Form*)), SLOT(slotFormWidgetSelected(KFormDesigner::Form*)));
 //		connect(m_manager, SIGNAL(noFormSelected()), SLOT(slotNoFormSelected()));
-		connect(m_manager, SIGNAL(undoEnabled(bool, const QString&)), SLOT(setUndoEnabled(bool, const QString&)));
-		connect(m_manager, SIGNAL(redoEnabled(bool, const QString&)), SLOT(setRedoEnabled(bool, const QString&)));
-
-		connect(m_manager, SIGNAL(dirty(KFormDesigner::Form*, bool)), this, SLOT(slotFormModified(KFormDesigner::Form*, bool)));
+		connect(KFormDesigner::FormManager::self(), SIGNAL(undoEnabled(bool, const QString&)), SLOT(setUndoEnabled(bool, const QString&)));
+		connect(KFormDesigner::FormManager::self(), SIGNAL(redoEnabled(bool, const QString&)), SLOT(setRedoEnabled(bool, const QString&)));
+		connect(KFormDesigner::FormManager::self(), SIGNAL(dirty(KFormDesigner::Form*, bool)), this, SLOT(slotFormModified(KFormDesigner::Form*, bool)));
 	}
 
 	container->show();
 	setWidget(container);
-	connect(m_workspace, SIGNAL(windowActivated(QWidget*)), m_manager, SLOT(windowChanged(QWidget*)));
+	connect(m_workspace, SIGNAL(windowActivated(QWidget*)), KFormDesigner::FormManager::self(), SLOT(windowChanged(QWidget*)));
 //	slotNoFormSelected();
+	KFormDesigner::FormManager::self()->emitNoFormSelected();
 }
 
 KFormDesignerPart::~KFormDesignerPart()
 {
 }
 
+KFormDesigner::WidgetLibrary* KFormDesignerPart::formsLibrary()
+{
+	return static_formsLibrary;
+}
+
 void
 KFormDesignerPart::setupActions()
 {
@@ -194,54 +202,56 @@ KFormDesignerPart::setupActions()
 	KStdAction::openNew(this, SLOT(createBlankForm()), actionCollection());
 	KStdAction::save(this, SLOT(save()), actionCollection());
 	KStdAction::saveAs(this, SLOT(saveAs()), actionCollection());
-	KStdAction::cut(m_manager, SLOT(cutWidget()), actionCollection());
-	KStdAction::copy(m_manager, SLOT(copyWidget()), actionCollection());
-	KStdAction::paste(m_manager, SLOT(pasteWidget()), actionCollection());
-	KStdAction::undo(m_manager, SLOT(undo()), actionCollection());
-	KStdAction::redo(m_manager, SLOT(redo()), actionCollection());
-	KStdAction::selectAll(m_manager, SLOT(selectAll()), actionCollection());
-	new KAction(i18n("Clear Widget Contents"), "editclear", KShortcut(0), m_manager, SLOT(clearWidgetContent()), actionCollection(), "clear_contents");
-	new KAction(i18n("Delete Widget"), "editdelete", KShortcut(0), m_manager, SLOT(deleteWidget()), actionCollection(), "edit_delete");
-	new KAction(i18n("Preview Form"), "filequickprint", ALT+Key_1, this, SLOT(slotPreviewForm()), actionCollection(), "preview_form");
-	new KAction(i18n("Edit Tab Order"), KShortcut(0), m_manager, SLOT(editTabOrder()), actionCollection(), "taborder");
-	new KAction(i18n("Edit Pixmap Collection"), "icons", KShortcut(0), m_manager, SLOT(editFormPixmapCollection()), actionCollection(), "pixmap_collection");
-	new KAction(i18n("Edit Form Connections"), KShortcut(0), m_manager, SLOT(editConnections()), actionCollection(), "form_connections");
+	KStdAction::cut(KFormDesigner::FormManager::self(), SLOT(cutWidget()), actionCollection());
+	KStdAction::copy(KFormDesigner::FormManager::self(), SLOT(copyWidget()), actionCollection());
+	KStdAction::paste(KFormDesigner::FormManager::self(), SLOT(pasteWidget()), actionCollection());
+	KStdAction::undo(KFormDesigner::FormManager::self(), SLOT(undo()), actionCollection());
+	KStdAction::redo(KFormDesigner::FormManager::self(), SLOT(redo()), actionCollection());
+	KStdAction::selectAll(KFormDesigner::FormManager::self(), SLOT(selectAll()), actionCollection());
+	new KAction(i18n("Clear Widget Contents"), "editclear", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(clearWidgetContent()), actionCollection(), "clear_contents");
+	new KAction(i18n("Delete Widget"), "editdelete", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(deleteWidget()), actionCollection(), "edit_delete");
+	new KAction(i18n("Preview Form"), "filequickprint", CTRL+Key_T, this, SLOT(slotPreviewForm()), actionCollection(), "preview_form");
+	new KAction(i18n("Edit Tab Order"), "tab_order", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(editTabOrder()), actionCollection(), "taborder");
+	new KAction(i18n("Edit Pixmap Collection"), "icons", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(editFormPixmapCollection()), actionCollection(), "pixmap_collection");
+	new KAction(i18n("Edit Form Connections"), "connections", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(editConnections()), actionCollection(), "form_connections");
 
-	KActionMenu *layoutMenu = new KActionMenu(i18n("Lay Out Widgets"), "", actionCollection(), "layout_menu");
-	layoutMenu->insert(new KAction(i18n("&Horizontally"), QString::null, KShortcut(0), m_manager, SLOT(layoutHBox()), actionCollection(), "layout_hbox"));
-	layoutMenu->insert(new KAction(i18n("&Vertically"), QString::null, KShortcut(0), m_manager, SLOT(layoutVBox()), actionCollection(), "layout_vbox"));
-	layoutMenu->insert(new KAction(i18n("In &Grid"), QString::null, KShortcut(0), m_manager, SLOT(layoutGrid()), actionCollection(), "layout_grid"));
-	layoutMenu->insert(new KAction(i18n("Horizontally in a &Splitter"), QString::null, KShortcut(0), m_manager, SLOT(layoutHSplitter()), actionCollection(), "layout_hsplitter"));
-	layoutMenu->insert(new KAction(i18n("Verti&cally in a Splitter"), QString::null, KShortcut(0), m_manager, SLOT(layoutVSplitter()), actionCollection(), "layout_vsplitter"));
-	new KAction(i18n("&Break Layout"), QString::null, KShortcut(0), m_manager, SLOT(breakLayout()), actionCollection(), "break_layout");
+	KActionMenu *layoutMenu = new KActionMenu(i18n("Group Widgets"), "", actionCollection(), "layout_menu");
+	layoutMenu->insert(new KAction(i18n("&Horizontally"), QString::null, KShortcut(0), KFormDesigner::FormManager::self(), SLOT(layoutHBox()), actionCollection(), "layout_hbox"));
+	layoutMenu->insert(new KAction(i18n("&Vertically"), QString::null, KShortcut(0), KFormDesigner::FormManager::self(), SLOT(layoutVBox()), actionCollection(), "layout_vbox"));
+	layoutMenu->insert(new KAction(i18n("In &Grid"), QString::null, KShortcut(0), KFormDesigner::FormManager::self(), SLOT(layoutGrid()), actionCollection(), "layout_grid"));
+	layoutMenu->insert(new KAction(i18n("By &Rows"), QString::null, KShortcut(0), KFormDesigner::FormManager::self(), SLOT(layoutHFlow()), actionCollection(), "layout_hflow"));
+	layoutMenu->insert(new KAction(i18n("By &Columns"), QString::null, KShortcut(0), KFormDesigner::FormManager::self(), SLOT(layoutVFlow()), actionCollection(), "layout_vflow"));
+	layoutMenu->insert(new KAction(i18n("Horizontally in &Splitter"), QString::null, KShortcut(0), KFormDesigner::FormManager::self(), SLOT(layoutHSplitter()), actionCollection(), "layout_hsplitter"));
+	layoutMenu->insert(new KAction(i18n("Verti&cally in Splitter"), QString::null, KShortcut(0), KFormDesigner::FormManager::self(), SLOT(layoutVSplitter()), actionCollection(), "layout_vsplitter"));
+	new KAction(i18n("&Ungroup Widgets"), QString::null, KShortcut(0), KFormDesigner::FormManager::self(), SLOT(breakLayout()), actionCollection(), "break_layout");
 
 /*
-	new KAction(i18n("Lay Out Widgets &Horizontally"), QString::null, KShortcut(0), m_manager, SLOT(layoutHBox()), actionCollection(), "layout_hbox");
-	new KAction(i18n("Lay Out Widgets &Vertically"), QString::null, KShortcut(0), m_manager, SLOT(layoutVBox()), actionCollection(), "layout_vbox");
-	new KAction(i18n("Lay Out Widgets in &Grid"), QString::null, KShortcut(0), m_manager, SLOT(layoutGrid()), actionCollection(), "layout_grid");
-	new KAction(i18n("Lay Out Widgets H&orizontally in a Splitter"), QString::null, KShortcut(0), m_manager, SLOT(layoutHSplitter()), actionCollection(), "layout_hsplitter");
-	new KAction(i18n("Lay Out Widgets Verti&cally in a Splitter"), QString::null, KShortcut(0), m_manager, SLOT(layoutVSplitter()), actionCollection(), "layout_vsplitter");
-	new KAction(i18n("&Break Layout"), QString::null, KShortcut(0), m_manager, SLOT(breakLayout()), actionCollection(), "break_layout");
+	new KAction(i18n("Lay Out Widgets &Horizontally"), QString::null, KShortcut(0), KFormDesigner::FormManager::self(), SLOT(layoutHBox()), actionCollection(), "layout_hbox");
+	new KAction(i18n("Lay Out Widgets &Vertically"), QString::null, KShortcut(0), KFormDesigner::FormManager::self(), SLOT(layoutVBox()), actionCollection(), "layout_vbox");
+	new KAction(i18n("Lay Out Widgets in &Grid"), QString::null, KShortcut(0), KFormDesigner::FormManager::self(), SLOT(layoutGrid()), actionCollection(), "layout_grid");
+	new KAction(i18n("Lay Out Widgets H&orizontally in Splitter"), QString::null, KShortcut(0), KFormDesigner::FormManager::self(), SLOT(layoutHSplitter()), actionCollection(), "layout_hsplitter");
+	new KAction(i18n("Lay Out Widgets Verti&cally in Splitter"), QString::null, KShortcut(0), KFormDesigner::FormManager::self(), SLOT(layoutVSplitter()), actionCollection(), "layout_vsplitter");
+	new KAction(i18n("&Break Layout"), QString::null, KShortcut(0), KFormDesigner::FormManager::self(), SLOT(breakLayout()), actionCollection(), "break_layout");
 */
-	new KAction(i18n("Bring Widget to Front"), "raise", KShortcut(0), m_manager, SLOT(bringWidgetToFront()), actionCollection(), "format_raise");
-	new KAction(i18n("Send Widget to Back"), "lower", KShortcut(0), m_manager, SLOT(sendWidgetToBack()), actionCollection(), "format_lower");
+	new KAction(i18n("Bring Widget to Front"), "raise", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(bringWidgetToFront()), actionCollection(), "format_raise");
+	new KAction(i18n("Send Widget to Back"), "lower", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(sendWidgetToBack()), actionCollection(), "format_lower");
 
 	KActionMenu *alignMenu = new KActionMenu(i18n("Align Widgets' Positions"), "aopos2grid", actionCollection(), "align_menu");
-	alignMenu->insert( new KAction(i18n("To Left"), "aoleft", KShortcut(0), m_manager, SLOT(alignWidgetsToLeft()), actionCollection(), "align_to_left") );
-	alignMenu->insert( new KAction(i18n("To Right"), "aoright", KShortcut(0), m_manager, SLOT(alignWidgetsToRight()), actionCollection(), "align_to_right") );
-	alignMenu->insert( new KAction(i18n("To Top"), "aotop", KShortcut(0), m_manager, SLOT(alignWidgetsToTop()), actionCollection(), "align_to_top") );
-	alignMenu->insert( new KAction(i18n("To Bottom"), "aobottom", KShortcut(0), m_manager, SLOT(alignWidgetsToBottom()), actionCollection(), "align_to_bottom") );
-	alignMenu->insert( new KAction(i18n("To Grid"), "aopos2grid", KShortcut(0), m_manager, SLOT(alignWidgetsToGrid()), actionCollection(), "align_to_grid") );
+	alignMenu->insert( new KAction(i18n("To Left"), "aoleft", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(alignWidgetsToLeft()), actionCollection(), "align_to_left") );
+	alignMenu->insert( new KAction(i18n("To Right"), "aoright", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(alignWidgetsToRight()), actionCollection(), "align_to_right") );
+	alignMenu->insert( new KAction(i18n("To Top"), "aotop", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(alignWidgetsToTop()), actionCollection(), "align_to_top") );
+	alignMenu->insert( new KAction(i18n("To Bottom"), "aobottom", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(alignWidgetsToBottom()), actionCollection(), "align_to_bottom") );
+	alignMenu->insert( new KAction(i18n("To Grid"), "aopos2grid", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(alignWidgetsToGrid()), actionCollection(), "align_to_grid") );
 
 	KActionMenu *sizeMenu = new KActionMenu(i18n("Adjust Widgets' Sizes"), "aogrid", actionCollection(), "adjust_size_menu");
-	sizeMenu->insert( new KAction(i18n("To Fit"), "aofit", KShortcut(0), m_manager, SLOT(adjustWidgetSize()), actionCollection(), "adjust_to_fit") );
-	sizeMenu->insert( new KAction(i18n("To Grid"), "aogrid", KShortcut(0), m_manager, SLOT(adjustSizeToGrid()), actionCollection(), "adjust_size_grid") );
-	sizeMenu->insert( new KAction(i18n("To Shortest"), "aoshortest", KShortcut(0), m_manager, SLOT(adjustHeightToSmall()), actionCollection(), "adjust_height_small") );
-	sizeMenu->insert( new KAction(i18n("To Tallest"), "aotallest", KShortcut(0), m_manager, SLOT(adjustHeightToBig()), actionCollection(), "adjust_height_big") );
-	sizeMenu->insert( new KAction(i18n("To Narrowest"), "aonarrowest", KShortcut(0), m_manager, SLOT(adjustWidthToSmall()), actionCollection(), "adjust_width_small") );
-	sizeMenu->insert( new KAction(i18n("To Widest"), "aowidest", KShortcut(0), m_manager, SLOT(adjustWidthToBig()), actionCollection(), "adjust_width_big") );
+	sizeMenu->insert( new KAction(i18n("To Fit"), "aofit", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(adjustWidgetSize()), actionCollection(), "adjust_to_fit") );
+	sizeMenu->insert( new KAction(i18n("To Grid"), "aogrid", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(adjustSizeToGrid()), actionCollection(), "adjust_size_grid") );
+	sizeMenu->insert( new KAction(i18n("To Shortest"), "aoshortest", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(adjustHeightToSmall()), actionCollection(), "adjust_height_small") );
+	sizeMenu->insert( new KAction(i18n("To Tallest"), "aotallest", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(adjustHeightToBig()), actionCollection(), "adjust_height_big") );
+	sizeMenu->insert( new KAction(i18n("To Narrowest"), "aonarrowest", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(adjustWidthToSmall()), actionCollection(), "adjust_width_small") );
+	sizeMenu->insert( new KAction(i18n("To Widest"), "aowidest", KShortcut(0), KFormDesigner::FormManager::self(), SLOT(adjustWidthToBig()), actionCollection(), "adjust_width_big") );
 
-	m_manager->createActions(actionCollection());
+	KFormDesigner::FormManager::self()->createActions(formsLibrary(), actionCollection());
 	if(m_inShell)
 		setXMLFile("kformdesigner_part_shell.rc");
 	else
@@ -251,18 +261,21 @@ KFormDesignerPart::setupActions()
 void
 KFormDesignerPart::createBlankForm()
 {
-	if(m_manager->activeForm() && m_uniqueFormMode)
+	if(KFormDesigner::FormManager::self()->activeForm() && m_uniqueFormMode)
 	{
 		m_openingFile = true;
 		closeURL();
 		m_openingFile = false;
 	}
 
-	if(m_uniqueFormMode && m_manager->activeForm() && !m_manager->activeForm()->isModified() && m_manager->activeForm()->filename().isNull())
+	if(m_uniqueFormMode && KFormDesigner::FormManager::self()->activeForm() 
+		&& !KFormDesigner::FormManager::self()->activeForm()->isModified() 
+		&& KFormDesigner::FormManager::self()->activeForm()->filename().isNull())
 		return;  // active form is already a blank one
 
 	QString n = i18n("Form") + QString::number(++m_count);
-	Form *form = new Form(m_manager, n.latin1());
+	Form *form = new Form(formsLibrary(), n.latin1(), 
+		false/*!designMode, we need to set it early enough*/);
 	FormWidgetBase *w = new FormWidgetBase(this, m_workspace, n.latin1());
 
 	w->setCaption(n);
@@ -272,7 +285,7 @@ KFormDesignerPart::createBlankForm()
 	w->setFocus();
 
 	form->createToplevel(w, w);
-	m_manager->importForm(form);
+	KFormDesigner::FormManager::self()->importForm(form);
 }
 
 void
@@ -288,7 +301,7 @@ KFormDesignerPart::open()
 bool
 KFormDesignerPart::openFile()
 {
-	Form *form = new Form(m_manager);
+	Form *form = new Form(formsLibrary());
 	FormWidgetBase *w = new FormWidgetBase(this, m_workspace);
 	form->createToplevel(w, w);
 
@@ -300,21 +313,22 @@ KFormDesignerPart::openFile()
 	}
 
 	w->show();
-	m_manager->importForm(form, !isReadWrite());
+	KFormDesigner::FormManager::self()->importForm(form, !isReadWrite());
 	return true;
 }
 
 bool
 KFormDesignerPart::saveFile()
 {
-	KFormDesigner::FormIO::saveFormToFile(m_manager->activeForm(), m_file);
+	KFormDesigner::FormIO::saveFormToFile(KFormDesigner::FormManager::self()->activeForm(), m_file);
 	return true;
 }
 
 void
 KFormDesignerPart::saveAs()
 {
-	KURL url = KFileDialog::getSaveURL("::kformdesigner", i18n("*.ui|Qt Designer UI Files"), m_workspace->topLevelWidget());
+	KURL url = KFileDialog::getSaveURL("::kformdesigner", i18n("*.ui|Qt Designer UI Files"), 
+		m_workspace->topLevelWidget());
 	if(url.isEmpty())
 		return;
 	else
@@ -349,7 +363,7 @@ KFormDesignerPart::closeForms()
 bool
 KFormDesignerPart::closeURL()
 {
-	if(!m_manager->activeForm())
+	if(!KFormDesigner::FormManager::self()->activeForm())
 		return true;
 
 	if(m_uniqueFormMode || !m_openingFile)
@@ -367,11 +381,11 @@ KFormDesignerPart::slotFormModified(Form *, bool isDirty)
 void
 KFormDesignerPart::slotPreviewForm()
 {
-	if(!m_manager->activeForm())
+	if(!KFormDesigner::FormManager::self()->activeForm())
 		return;
 
 	FormWidgetBase *w = new FormWidgetBase(this, m_workspace);
-	m_manager->previewForm(m_manager->activeForm(), w);
+	KFormDesigner::FormManager::self()->previewForm(KFormDesigner::FormManager::self()->activeForm(), w);
 }
 
 #if 0
@@ -419,7 +433,7 @@ KFormDesignerPart::slotWidgetSelected(Form *form, bool multiple)
 	ENABLE_ACTION("layout_hsplitter", twoSelected);
 	ENABLE_ACTION("layout_vsplitter", twoSelected);
 
-	KFormDesigner::Container *container = m_manager->activeForm()->activeContainer();
+	KFormDesigner::Container *container = KFormDesigner::FormManager::self()->activeForm()->activeContainer();
 	ENABLE_ACTION("break_layout", (container->layoutType() != KFormDesigner::Container::NoLayout));
 }
 
@@ -457,7 +471,7 @@ KFormDesignerPart::slotNoFormSelected()
 	ENABLE_ACTION("pixmap_collection", false);
 	ENABLE_ACTION("form_connections", false);
 	ENABLE_ACTION("taborder", false);
-	ENABLE_ACTION("change_style", m_manager->activeForm());
+	ENABLE_ACTION("change_style", KFormDesigner::FormManager::self()->activeForm());
 
 	// Disable items in 'File'
 	ENABLE_ACTION("file_save", false);
@@ -479,7 +493,7 @@ KFormDesignerPart::enableFormActions()
 	ENABLE_ACTION("file_save_as", true);
 	ENABLE_ACTION("preview_form", true);
 
-	ENABLE_ACTION("edit_paste", m_manager->isPasteEnabled());
+	ENABLE_ACTION("edit_paste", KFormDesigner::FormManager::self()->isPasteEnabled());
 	ENABLE_ACTION("edit_select_all", true);
 }
 
@@ -678,7 +692,7 @@ FormWidgetBase::highlightWidgets(QWidget *from, QWidget *to)//, const QPoint &po
 void
 FormWidgetBase::closeEvent(QCloseEvent *ev)
 {
-	Form *form = m_part->manager()->formForWidget(this);
+	Form *form = KFormDesigner::FormManager::self()->formForWidget(this);
 	if(!form || !form->isModified() || !form->objectTree()) // == preview form
 		ev->accept();
 	else
@@ -691,7 +705,7 @@ FormWidgetBase::closeEvent(QCloseEvent *ev)
 	}
 }
 
-K_EXPORT_COMPONENT_FACTORY(libkformdesigner_part, KFDFactory);
+K_EXPORT_COMPONENT_FACTORY(libkformdesigner_part, KFDFactory)
 
 #include "kfd_part.moc"
 
