@@ -2274,7 +2274,7 @@ KexiDB::TableSchema* Connection::setupTableSchema( const RowData &data )
 		}
 
 		Field *f = new Field(
-			cursor->value(2).asString(), (Field::Type)f_type, f_constr, f_len, f_prec, f_opts );
+			cursor->value(2).asString(), (Field::Type)f_type, f_constr, f_opts, f_len, f_prec );
 		f->setDefaultValue( cursor->value(7).toCString() );
 		f->m_caption = cursor->value(9).asString();
 		f->m_desc = cursor->value(10).asString();
