@@ -27,6 +27,7 @@
 #include <kapplication.h>
 
 #include <kexiutils/tristate.h> 
+#include "migratemanager.h"
 
 class QLabel;
 class QCheckBox;
@@ -140,6 +141,7 @@ private:
 	QMap<QString,QString> *m_args;
 	QString m_predefinedDatabaseName, m_predefinedMimeType;
 	KexiDB::ConnectionData *m_predefinedConnectionData;
+	MigrateManager m_migrateManager; //!< object lives here, so status messages can be globally preserved
 
 	//! Encoding for source db. Currently only used for MDB driver.
 //! @todo Hardcoded. Move to KexiMigrate driver's impl.
