@@ -40,6 +40,7 @@
 #include <qtextcodec.h>
 #include <qtimer.h>
 #include <qfontmetrics.h>
+#include <qtooltip.h>
 
 #include <kapplication.h>
 #include <kdebug.h>
@@ -52,6 +53,7 @@
 #include <kcharsets.h>
 #include <knuminput.h>
 #include <kprogress.h>
+#include <kactivelabel.h>
 
 #include <kexiutils/identifier.h>
 #include <kexiutils/utils.h>
@@ -94,7 +96,9 @@
 //extra:
 #define _NO_TYPE_YET -1 //allows to accept a number of empty cells, before something non-empty
 #define _FP_NUMBER_TYPE 255 //_NUMBER_TYPE variant
-#define MAX_COLUMNS 100 //max 100 columns is reasonable
+#define MAX_ROWS_TO_PREVIEW 100 //max 100 rows is reasonable
+#define MAX_BYTES_TO_PREVIEW 10240 //max 10KB is reasonable
+#define MAX_CHARS_TO_SCAN_WHILE_DETECTING_DELIMITER 4096
 
 class KexiCSVImportDialogTable : public QTable
 {
@@ -161,7 +165,9 @@ KexiCSVImportDialog::KexiCSVImportDialog( Mode mode, KexiMainWindow* mainWin,
 	m_primaryKeyColumn(-1),
 	m_dialogCancelled(false),
 	m_conn(0),
-	m_destinationTableSchema(0)
+	m_destinationTableSchema(0),
+	m_allRowsLoadedInPreview(false),
+	m_stoppedAt_MAX_BYTES_TO_PREVIEW(false)
 {
 	setWFlags(getWFlags() | Qt::WStyle_Maximize | Qt::WStyle_SysMenu);
 	hide();
@@ -175,7 +181,8 @@ KexiCSVImportDialog::KexiCSVImportDialog( Mode mode, KexiMainWindow* mainWin,
 	m_typeNames[4] = i18n("date/time");
 
 	kapp->config()->setGroup("ImportExport");
-	m_maximumRowsForPreview = kapp->config()->readNumEntry("MaximumRowsForPreviewInImportDialog", MAX_COLUMNS);
+	m_maximumRowsForPreview = kapp->config()->readNumEntry("MaximumRowsForPreviewInImportDialog", MAX_ROWS_TO_PREVIEW);
+	m_maximumBytesForPreview = kapp->config()->readNumEntry("MaximumBytesForPreviewInImportDialog", MAX_BYTES_TO_PREVIEW);
 
 	m_pkIcon = SmallIcon("key");
 
@@ -292,7 +299,7 @@ if ( m_mode == Clipboard )
 	m_dateRegExp2 = QRegExp("\\d{1,2}[/\\-\\.]\\d{1,2}[/\\-\\.]\\d{1,4}");
 	m_timeRegExp1 = QRegExp("\\d{1,2}:\\d{1,2}:\\d{1,2}");
 	m_timeRegExp2 = QRegExp("\\d{1,2}:\\d{1,2}");
-	m_fpNumberRegExp = QRegExp("\\d*[,\\.]\\d+");
+	m_fpNumberRegExp = QRegExp("[\\-]{0,1}\\d*[,\\.]\\d+");
 
 	if (m_mode == File) {
 		QStringList mimetypes( csvMimeTypes() );
@@ -325,7 +332,7 @@ if ( m_mode == Clipboard )
 	}
 	else if (m_mode == Clipboard) {
 		QCString subtype("plain");
-		m_data = QApplication::clipboard()->text(subtype, QClipboard::Clipboard);
+		m_clipboardData = QApplication::clipboard()->text(subtype, QClipboard::Clipboard);
 /* debug
 		for (int i=0;QApplication::clipboard()->data(QClipboard::Clipboard)->format(i);i++)
 			kdDebug() << i << ": " 
@@ -349,7 +356,7 @@ if ( m_mode == Clipboard )
 	if (m_mode==Clipboard) {
 		m_infoLbl->setIcon("editpaste");
 	}
-	updateRowCountInfo();
+	//updateRowCountInfo();
 
 	m_table->setSelectionMode(QTable::NoSelection);
 
@@ -387,29 +394,6 @@ void KexiCSVImportDialog::initLater()
 	if (!openData())
 		return;
 
-	QChar detectedDelimiter;
-	if (m_mode==File) { //only detect for File mode
-		// try to detect delimiter
-		// \t has priority, then , then ;
-		for (uint i=0; i < QMIN(4096, m_data.length()); i++) {
-			const QChar c(m_data[i]);
-			if (c=='\t') {
-				detectedDelimiter = c;
-				break;
-			}
-			else if (c==',' && detectedDelimiter!='\t') {
-				detectedDelimiter = c;
-			}
-			else if (c==';' && detectedDelimiter!='\t' && detectedDelimiter!=',') {
-				detectedDelimiter = c;
-			}
-		}
-	}
-	if (detectedDelimiter.isNull())
-		detectedDelimiter = m_mode==File 
-			? KEXICSV_DEFAULT_FILE_DELIMITER[0] : KEXICSV_DEFAULT_CLIPBOARD_DELIMITER[0]; //<-- defaults
-
-	m_delimiterWidget->setDelimiter(QString(detectedDelimiter));
 //	delimiterChanged(detectedDelimiter); // this will cause fillTable()
 	m_columnsAdjusted = false;
 	fillTable();
@@ -537,15 +521,16 @@ void KexiCSVImportDialog::fillTable()
 		m_table->setPixmap(0, m_primaryKeyColumn, m_pkIcon);
 
 	const int count = QMAX(0, m_table->numRows()-1+m_startline);
-	const bool allRowsLoaded = count < m_maximumRowsForPreview;
-	if (allRowsLoaded) {
+	m_allRowsLoadedInPreview = count < m_maximumRowsForPreview && !m_stoppedAt_MAX_BYTES_TO_PREVIEW;
+	if (m_allRowsLoadedInPreview) {
 		m_startAtLineSpinBox->setMaxValue(count);
 		m_startAtLineSpinBox->setValue(m_startline+1);
 	}
 	m_startAtLineLabel->setText(i18n( "Start at line%1:").arg(
-			allRowsLoaded ? QString(" (1-%1)").arg(count)
+			m_allRowsLoadedInPreview ? QString(" (1-%1)").arg(count)
 			: QString::null //we do not know what's real count
 	));
+	updateRowCountInfo();
 
 	m_blockUserEvents = false;
 	repaint();
@@ -553,12 +538,39 @@ void KexiCSVImportDialog::fillTable()
 	m_table->horizontalScrollBar()->repaint();//avoid missing repaint
 }
 
+QString KexiCSVImportDialog::detectDelimiterByLookingAtFirstBytesOfFile(QTextStream& inputStream)
+{
+	QChar detectedDelimiter;
+	// try to detect delimiter
+	// \t has priority, then ; then ,
+	const QIODevice::Offset origOffset = inputStream.device()->at();
+	QChar c;
+	m_file->at(0);
+	for (uint i=0; !inputStream.atEnd() && i < MAX_CHARS_TO_SCAN_WHILE_DETECTING_DELIMITER; i++) {
+		(*m_inputStream) >> c; // read one char
+		if (c=='\t') {
+			detectedDelimiter = c;
+			break;
+		}
+		else if (c==';' && detectedDelimiter!='\t') {
+			detectedDelimiter = c;
+			break;
+		}
+		else if (c==',' && detectedDelimiter!='\t' && detectedDelimiter!=';') {
+			detectedDelimiter = c;
+		}
+	}
+	inputStream.device()->at(origOffset); //restore orig. offset
+	if (detectedDelimiter.isNull())
+		return KEXICSV_DEFAULT_FILE_DELIMITER; //<-- default
+	return QString( detectedDelimiter );
+}
+
 tristate KexiCSVImportDialog::loadRows(QString &field, int &row, int &column, int &maxColumn, 
 	bool inGUI)
 {
 	enum { S_START, S_QUOTED_FIELD, S_MAYBE_END_OF_QUOTED_FIELD, S_END_OF_QUOTED_FIELD,
 		 S_MAYBE_NORMAL_FIELD, S_NORMAL_FIELD } state = S_START;
-	const QChar delimiter(m_delimiterWidget->delimiter()[0]);
 	field = QString::null;
 	const bool ignoreDups = m_ignoreDuplicates->isChecked();
 	bool lastCharDelimiter = false;
@@ -568,7 +580,8 @@ tristate KexiCSVImportDialog::loadRows(QString &field, int &row, int &column, in
 	QChar x;
 	delete m_inputStream;
 	if ( m_mode == Clipboard ) {
-		m_inputStream = new QTextStream(m_data, IO_ReadOnly);
+		m_inputStream = new QTextStream(m_clipboardData, IO_ReadOnly);
+		m_delimiterWidget->setDelimiter(KEXICSV_DEFAULT_CLIPBOARD_DELIMITER);
 	}
 	else {
 		m_file->at(0); //always seek at 0 because loadRows() is called many times
@@ -578,15 +591,21 @@ tristate KexiCSVImportDialog::loadRows(QString &field, int &row, int &column, in
 			if (codec)
 				m_inputStream->setCodec(codec); //QTextCodec::codecForName("CP1250"));
 		}
+		const QString delimiter( detectDelimiterByLookingAtFirstBytesOfFile(*m_inputStream) );
+		if (m_delimiterWidget->delimiter() != delimiter)
+			m_delimiterWidget->setDelimiter( delimiter );
 	}
+	const QChar delimiter(m_delimiterWidget->delimiter()[0]);
+	m_stoppedAt_MAX_BYTES_TO_PREVIEW = false;
 	int progressStep = 0;
 	if (m_importingProgressDlg)
 		progressStep = QMAX( 1, m_importingProgressDlg->progressBar()->totalSteps()/200 );
 	int offset = 0;
 	for (;!m_inputStream->atEnd(); offset++)
 	{
-		if (column >= m_maximumRowsForPreview)
-			return true;
+//disabled: this breaks wide spreadsheets
+//	if (column >= m_maximumRowsForPreview)
+//		return true;
 
 		if (m_importingProgressDlg && ((offset % progressStep) < 5)) {
 			//update progr. bar dlg on final exporting
@@ -755,13 +774,13 @@ tristate KexiCSVImportDialog::loadRows(QString &field, int &row, int &column, in
 			lastCharDelimiter = false;
 
 		if (nextRow) {
-			nextRow = false;
 			if (!inGUI && row==1 && m_1stRowForFieldNames->isChecked()) {
 				// do not save to the database 1st row if it contains column names
 				m_importingStatement->clearArguments();
 			}
 			else if (!saveRow(inGUI))
 				return false;
+	
 			++row;
 		}
 
@@ -800,6 +819,15 @@ tristate KexiCSVImportDialog::loadRows(QString &field, int &row, int &column, in
 				<< m_maximumRowsForPreview << endl;
 			break;
 		}
+		if (nextRow) {
+			nextRow = false;
+			//additional speedup: stop processing now if too many bytes were loaded for preview
+			kexipluginsdbg << offset << endl;
+			if (inGUI && offset >= m_maximumBytesForPreview && row >= 2) {
+				m_stoppedAt_MAX_BYTES_TO_PREVIEW = true;
+				return true;
+			}
+		}
 	}
 	return true;
 }
@@ -858,6 +886,16 @@ void KexiCSVImportDialog::detectTypeAndUniqueness(int row, int col, const QStrin
 		if (text.isEmpty() && type==_NO_TYPE_YET)
 			found = true; //real type should be found later
 		//detect type because it's 1st row or all prev. rows were not text
+		//-FP number? (trying before "number" type is a must)
+		if (!found && (row==1 || type==_NUMBER_TYPE || type==_FP_NUMBER_TYPE || type==_NO_TYPE_YET)) {
+			bool ok = text.isEmpty() || m_fpNumberRegExp.exactMatch(text);
+			//if (!ok)
+			//	text.toDouble(&ok);
+			if (ok && (row==1 || type==_NUMBER_TYPE || type==_FP_NUMBER_TYPE || type==_NO_TYPE_YET)) {
+				m_detectedTypes[col]=_FP_NUMBER_TYPE;
+				found = true; //yes
+			}
+		}
 		//-number?
 		if (!found && (row==1 || type==_NUMBER_TYPE || type==_NO_TYPE_YET)) {
 			bool ok = text.isEmpty();//empty values allowed
@@ -868,16 +906,6 @@ void KexiCSVImportDialog::detectTypeAndUniqueness(int row, int col, const QStrin
 				found = true; //yes
 			}
 		}
-		//-FP number?
-		if (!found && (row==1 || type==_FP_NUMBER_TYPE || type==_NO_TYPE_YET)) {
-			bool ok = text.isEmpty() || m_fpNumberRegExp.exactMatch(text);
-			if (!ok)
-				text.toInt(&ok);
-			if (ok && (row==1 || type==_NO_TYPE_YET)) {
-				m_detectedTypes[col]=_FP_NUMBER_TYPE;
-				found = true; //yes
-			}
-		}
 		//-date?
 		if (!found && (row==1 || type==_DATE_TYPE || type==_NO_TYPE_YET)) {
 			if ((row==1 || type==_NO_TYPE_YET)
@@ -958,7 +986,16 @@ void KexiCSVImportDialog::setText(int row, int col, const QString& text, bool in
 //! @todo what about time and float/double types and different integer subtypes?
 		}
 		else if (detectedType==_FP_NUMBER_TYPE) {
-			*m_importingStatement << ( text.isEmpty() ? QVariant() : text.toDouble() );
+			//replace ',' with '.'
+			QCString t(text.latin1());
+			const int textLen = t.length();
+			for (int i=0; i<textLen; i++) {
+				if (t.at(i)==',') {
+					t.at(i) = '.';
+					break;
+				}
+			}
+			*m_importingStatement << ( t.isEmpty() ? QVariant() : t.toDouble() );
 		}
 		else if (detectedType==_DATE_TYPE) {
 			QDate date( QDate::fromString(text, Qt::ISODate) ); //same as m_dateRegExp1
@@ -1043,7 +1080,7 @@ void KexiCSVImportDialog::setText(int row, int col, const QString& text, bool in
 		m_adjustRows=1;
 	}
 
-	m_table->setText(row - 1, col - 1, text);
+	m_table->setText(row - 1, col - 1, text.stripWhiteSpace());
 	m_table->verticalHeader()->setLabel(row-1, QString::number(row-1));
 
 	detectTypeAndUniqueness(row-1, col-1, text);
