@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include "kexiinputtableedit.h"
@@ -35,7 +35,7 @@
 #include <kcompletionbox.h>
 #include <knumvalidator.h>
 
-
+//! @internal
 class MyLineEdit : public KLineEdit
 {
 	public:
@@ -150,13 +150,13 @@ void KexiInputTableEdit::setValueInternal(const QVariant& add_, bool removeOld)
 		QString add(add_.toString());
 
 		if (field()->isFPNumericType()) {
-//TODO: precision!
+//! @todo precision!
 			tmp_val = QString::number(origValue.toDouble(), 'f', 2/*prec*/);
 			if (origValue.toDouble() == 0.0) {
 				tmp_val=add; //eat 0
 			}
 			else {
-				//TODO(js): get decimal places settings here...
+//! @todo (js): get decimal places settings here...
 				QStringList sl = QStringList::split(".", tmp_val);
 				if (tmp_val.isEmpty())
 					m_lineedit->setText("");
@@ -201,7 +201,7 @@ void KexiInputTableEdit::setValueInternal(const QVariant& add_, bool removeOld)
 		}
 
 		if (tmp_val.isEmpty()) {
-			if (origValue.isNull()) {
+			if (origValue.toString().isEmpty()) {
 				//we have to set NULL initial value:
 				m_lineedit->setText(QString::null);
 			}
@@ -317,7 +317,6 @@ QVariant KexiInputTableEdit::value()
 //			QString v;
 			if(!m_calculatedCell)
 			{
-				qDebug("KexiInputTableEdit::value() converting => %s", m_cview->text().latin1());
 				v = m_cview->text().replace(QRegExp("\\" + KGlobal::locale()->thousandsSeparator()), "");
 				v = v.replace(QRegExp("\\" + KGlobal::locale()->decimalSymbol()), ".");
 				v = v.replace(QRegExp("\\" + KGlobal::locale()->negativeSign()), "-");
@@ -332,7 +331,6 @@ QVariant KexiInputTableEdit::value()
 				QString real = m_cview->text().right(m_cview->text().length() - 1);
 				real = real.replace(QRegExp("\\" + KGlobal::locale()->thousandsSeparator()), "");
 				real = real.replace(QRegExp("\\" + KGlobal::locale()->decimalSymbol()), ".");
-//				qDebug("KexiInputTableEdit::value() calculating '%s'", real.latin1());
 				QStringList values = QStringList::split(QRegExp("[\\+|\\*|\\/|-]"), real, false);
 				QStringList ops = QStringList::split(QRegExp("[0-9]{1,8}(?:\\.[0-9]+)?"), real, false);
 
@@ -423,20 +421,6 @@ QSize KexiInputTableEdit::totalSize()
 	return m_lineedit->size();
 }
 
-//======================================================
-
-KexiInputEditorFactoryItem::KexiInputEditorFactoryItem()
-{
-}
-
-KexiInputEditorFactoryItem::~KexiInputEditorFactoryItem()
-{
-}
-
-KexiTableEdit* KexiInputEditorFactoryItem::createEditor(
-	KexiTableViewColumn &column, QScrollView* parent)
-{
-	return new KexiInputTableEdit(column, parent);
-}
+KEXI_CELLEDITOR_FACTORY_ITEM_IMPL(KexiInputEditorFactoryItem, KexiInputTableEdit)
 
 #include "kexiinputtableedit.moc"
