@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef KIVIO_DOC_IFACE_H
@@ -34,7 +34,6 @@ public:
     KIvioDocIface(  KivioDoc *doc_ );
 
 k_dcop:
-    virtual void aboutKivio();
     virtual DCOPRef map();
     void initConfig();
     void saveConfig();
