@@ -14,14 +14,15 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #ifndef KIVIO_CUSTOM_DRAG_DATA_H
 #define KIVIO_CUSTOM_DRAG_DATA_H
 
 class KivioPage;
+#include <koffice_export.h>
 
-class KivioCustomDragData
+class KIVIO_EXPORT KivioCustomDragData
 {
 public:
     KivioCustomDragData();
