@@ -234,6 +234,9 @@ template <class T> void KisTransformWorker::transformPass(KisPaintDevice *src, K
     scale = int(floatscale*srcLen);
     scaleDenom = srcLen;
 
+    if(scaleDenom == 0)
+        return;
+
     Q_INT32 support = filterStrategy->intSupport();
     Q_INT32 dstLen, dstStart;
     Q_INT32 invfscale = 256;
@@ -304,7 +307,21 @@ template <class T> void KisTransformWorker::transformPass(KisPaintDevice *src, K
                 sum+=filterWeights[center].weight[num];
             }
         }
-//printf("  sum2 =%d\n",sum);
+
+//printf("  sum2 =%d",sum);
+        int num = 0; 
+        while(sum<255 && num*2<span)
+        {
+            filterWeights[center].weight[span/2 + num]++;
+            ++sum;
+            if(sum<255 && num<span/2)
+            {
+                filterWeights[center].weight[span/2 - num - 1]++;
+                ++sum;
+            }
+            ++num;
+        }
+//printf("  sum3 =%d\n",sum);
 
         filterWeights[center].numWeights = span;
     }
@@ -321,7 +338,7 @@ template <class T> void KisTransformWorker::transformPass(KisPaintDevice *src, K
 
         // Build a temporary line
         T srcIt = createIterator <T>(src, srcStart - extraLen, lineNum, srcLen+2*extraLen);
-        int i = 0;
+        Q_INT32 i = 0;
         while(!srcIt.isDone())
         {
             Q_UINT8 *data;
@@ -348,10 +365,18 @@ template <class T> void KisTransformWorker::transformPass(KisPaintDevice *src, K
         i=0;
         while(!dstIt.isDone())
         {
-            if(scale < 0)
-                center = (srcLen<<8) + (((i<<8)) * scaleDenom) / scale;
+            if(scaleDenom<2500)
+                center = ((i<<8) * scaleDenom) / scale;
             else
-                center = (((i<<8)) * scaleDenom) / scale;
+            {
+                if(scaleDenom<46000) // real limit is actually 46340 pixels
+                    center = ((i * scaleDenom) / scale)<<8;
+                else
+                    center = ((i<<8)/scale * scaleDenom) / scale; // XXX fails for sizes over 2^23 pixels src width
+            }
+
+            if(scale < 0)
+                center += srcLen<<8;
 
             center += (extraLen<<8) + shearFracOffset;
 
