@@ -10,21 +10,27 @@
 #include <kparts/event.h>
 #include <koffice_export.h>
 
-class KSPREAD_EXPORT KSpreadSelectionChanged : public KParts::Event
+#include "region.h"
+namespace KSpread
+{
+
+class KSPREAD_EXPORT SelectionChanged : public KParts::Event
 {
 public:
-    KSpreadSelectionChanged( const QRect&, const QString& sheet );
-    ~KSpreadSelectionChanged();
+    SelectionChanged( const Region&, const QString& sheet );
+    ~SelectionChanged();
 
-    QRect rect() const { return m_rect; }
+    Region region() const { return m_region; }
     QString sheet() const { return m_sheet; }
 
     static bool test( const QEvent* e ) { return KParts::Event::test( e, s_strSelectionChanged ); }
 
 private:
     static const char *s_strSelectionChanged;
-    QRect m_rect;
+    Region m_region;
     QString m_sheet;
 };
 
+} // namespace KSpread
+
 #endif
