@@ -6,14 +6,19 @@
 class QDomElement;
 class QDomDocument;
 
-class KSpreadLocale : public KLocale
+namespace KSpread
+{
+
+class Locale : public KLocale
 {
 public:
-    KSpreadLocale();
+    Locale();
     
     void load( const QDomElement& element );
     QDomElement save( QDomDocument& doc ) const;
     void defaultSystemConfig();
 };
 
+} //namespace KSpread
+
 #endif
