@@ -13,18 +13,26 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __kspread_map_h__
 #define __kspread_map_h__
 
-class KSpreadChanges;
-class KSpreadMap;
-class KSpreadDoc;
+#include <qcstring.h>
+#include <qptrlist.h>
+#include <qstring.h>
+#include <qstringlist.h>
+#include <qintdict.h>
+#include <qobject.h>
+#include <qdict.h>
+
+#include <koffice_export.h>
 
 class KoStore;
+class KoOasisLoadingContext;
+class KoOasisStyles;
 
 class DCOPObject;
 
@@ -34,42 +42,42 @@ class KoXmlWriter;
 class KoGenStyles;
 class KoOasisSettings;
 
-#include <qcstring.h>
-#include <qptrlist.h>
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qintdict.h>
-#include <qobject.h>
-
-#include "kspread_sheet.h"
+namespace KSpread
+{
+class Changes;
+class Map;
+class Doc;
+class Sheet;
+class GenValidationStyles;
+class Style;
 
 /**
   A map is a simple container for all sheets. Usually a complete map
   is saved in one file.
  */
-class KSPREAD_EXPORT KSpreadMap : public QObject
+class KSPREAD_EXPORT Map : public QObject
 {
 Q_OBJECT
 public:
   /**
    * Created an empty map.
    */
-  KSpreadMap ( KSpreadDoc* doc, const char* name = 0);
+  Map(Doc* doc, const char* name = 0);
   /**
    * This deletes all sheets contained in this map.
    */
-  virtual ~KSpreadMap();
-  
-  KSpreadDoc* doc();
+  virtual ~Map();
+
+  Doc* doc() const;
 
   QDomElement save( QDomDocument& doc );
 
     void saveOasisSettings( KoXmlWriter &settingsWriter );
     void loadOasisSettings( KoOasisSettings &settings );
 
-    bool saveOasis( KoXmlWriter & xmlWriter, KoGenStyles & mainStyles );
+    bool saveOasis( KoXmlWriter & xmlWriter, KoGenStyles & mainStyles, KoStore *store, KoXmlWriter* manifestWriter, int &_indexObj, int &_partIndexObj );
 
-    bool loadOasis( const QDomElement& mymap, KoOasisStyles& oasisStyles );
+  bool loadOasis( const QDomElement& mymap, KoOasisLoadingContext& oasisContext , QDict<Style>& styleMap );
   bool loadXML( const QDomElement& mymap );
   bool loadChildren( KoStore* _store );
 
@@ -81,45 +89,53 @@ public:
   bool checkPassword( QCString const & passwd ) const { return ( passwd == m_strPassword ); }
 
   /**
-   * The sheet named @param _from is being moved to the sheet @param _to.
-   * If @param _before is true @param _from is inserted before (after otherwise)   * @param _to.
+   * The sheet named @p _from is being moved to the sheet @p _to.
+   * If @p  _before is true @p _from is inserted before (after otherwise)   
+   * @p  _to.
    */
   void moveSheet( const QString & _from, const QString & _to, bool _before = true );
 
-  KSpreadSheet* findSheet( const QString & _name );
-  KSpreadSheet* nextSheet( KSpreadSheet* );
-  KSpreadSheet* previousSheet( KSpreadSheet* );
+  /**
+   * searches for a sheet named @p _name
+   * @return a pointer to the searched sheet, @c 0 if nothing was found
+   */
+  Sheet* findSheet( const QString & _name );
+  Sheet* nextSheet( Sheet* );
+  Sheet* previousSheet( Sheet* );
+
+  Sheet* initialActiveSheet()const { return m_initialActiveSheet; }
+  int initialMarkerColumn() const { return m_initialMarkerColumn; }
+  int initialMarkerRow()    const { return m_initialMarkerRow; }
+  double initialXOffset()   const { return m_initialXOffset; }
+  double initialYOffset()   const { return m_initialYOffset; }
 
-  KSpreadSheet* initialActiveSheet()const { return m_initialActiveSheet; }
-  int initialMarkerColumn()const { return m_initialMarkerColumn; }
-  int initialMarkerRow()const { return m_initialMarkerRow; }
 
   /**
-   * @return a pointer to a new KSpreadSheet. The KSpreadSheet is not added
+   * @return a pointer to a new Sheet. The Sheet is not added
    *         to the map nor added to the GUI.
    */
-  KSpreadSheet * createSheet();
+  Sheet * createSheet();
   /** add sheet to the map, making it active */
-  void addSheet( KSpreadSheet *_sheet );
+  void addSheet( Sheet *_sheet );
 
   /** add a new sheet to the map, returning a pointer to it */
-  KSpreadSheet *addNewSheet ();
-  
+  Sheet *addNewSheet ();
+
   /**
    * Use the @ref #nextSheet function to get all the other sheets.
    * Attention: Function is not reentrant.
    *
    * @return a pointer to the first sheet in this map.
    */
-  KSpreadSheet* firstSheet() { return m_lstSheets.first();  }
+  Sheet* firstSheet() { return m_lstSheets.first();  }
 
   /**
-   * Use the @ref #previousSheet function to get all the other sheets.
+   * Use the previousSheet() function to get all the other sheets.
    * Attention: Function is not reentrant.
    *
    * @return a pointer to the last sheet in this map.
    */
-  KSpreadSheet* lastSheet() { return m_lstSheets.last();  }
+  Sheet* lastSheet() { return m_lstSheets.last();  }
 
   /**
    * Call @ref #firstSheet first. This will set the list pointer to
@@ -127,9 +143,9 @@ public:
    *
    * @return a pointer to the next sheet in this map.
    */
-  KSpreadSheet* nextSheet() { return m_lstSheets.next();  }
+  Sheet* nextSheet() { return m_lstSheets.next();  }
 
-  QPtrList<KSpreadSheet>& sheetList() { return m_lstSheets; }
+  QPtrList<Sheet>& sheetList() { return m_lstSheets; }
 
   /**
    * @return amount of sheets in this map.
@@ -146,8 +162,8 @@ public:
 
   virtual DCOPObject* dcopObject();
 
-  void takeSheet( KSpreadSheet * sheet );
-  void insertSheet( KSpreadSheet * sheet );
+  void takeSheet( Sheet * sheet );
+  void insertSheet( Sheet * sheet );
 
   QStringList visibleSheets() const;
   QStringList hiddenSheets() const;
@@ -159,16 +175,16 @@ signals:
   /**
    * Emitted if a new table is added to the document.
    */
-  void sig_addSheet( KSpreadSheet *_table );
+  void sig_addSheet( Sheet *_table );
 private:
 
-  KSpreadDoc* m_doc;
+  Doc* m_doc;
 
   /**
    * List of all sheets in this map. The list has autodelete turned on.
    */
-  QPtrList<KSpreadSheet> m_lstSheets;
-  QPtrList<KSpreadSheet> m_lstDeletedSheets;
+  QPtrList<Sheet> m_lstSheets;
+  QPtrList<Sheet> m_lstDeletedSheets;
 
   /**
    * Password to protect the map from being changed.
@@ -177,14 +193,18 @@ private:
   /**
    * Set from the XML
    */
-  KSpreadSheet * m_initialActiveSheet;
+  Sheet * m_initialActiveSheet;
   int m_initialMarkerColumn;
   int m_initialMarkerRow;
-  
-  // used to give every KSpreadSheet a unique default name.
+  double m_initialXOffset;
+  double m_initialYOffset;
+
+  // used to give every Sheet a unique default name.
   int tableId;
 
   DCOPObject* m_dcop;
 };
 
+} // namespace KSpread
+
 #endif
