@@ -251,7 +251,7 @@ public:
 
     void loadOasisObjects( const QDomElement& e, KoOasisLoadingContext& oasisContext );
     void loadOasisSettings( const KoOasisSettings::NamedMap &settings );
-    void saveOasisSettings( KoXmlWriter &settingsWriter, const QPoint& marker ) const;
+    void saveOasisSettings( KoXmlWriter &settingsWriter ) const;
     void saveOasisPrintStyleLayout( KoGenStyle &style ) const;
 
     /**
@@ -1292,13 +1292,14 @@ protected:
 
     QString saveOasisSheetStyleName( KoGenStyles &mainStyles );
     void saveOasisColRowCell( KoXmlWriter& xmlWriter, KoGenStyles &mainStyles, int maxCols, int maxRows, GenValidationStyles &valStyle );
-    void saveOasisCells( KoXmlWriter& xmlWriter, KoGenStyles& mainStyles,
-                         int row, GenValidationStyles& valStyle );
+    void saveOasisCells(  KoXmlWriter& xmlWriter, KoGenStyles &mainStyles, int row, int maxCols, GenValidationStyles &valStyle );
     void convertPart( const QString & part, KoXmlWriter & writer ) const;
     void addText( const QString & text, KoXmlWriter & writer ) const;
 
     void maxRowCols( int & maxCols, int & maxRows );
 
+    bool rowAsCell( int row, int maxCols );
+
     QString getPart( const QDomNode & part );
     void replaceMacro( QString & text, const QString & old, const QString & newS );
 
