@@ -13,28 +13,31 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
-
-#include "kspread_style.h"
-#include "kspread_style_manager.h"
-#include <koOasisStyles.h>
-#include <koxmlns.h>
-#include <kdebug.h>
-#include <klocale.h>
 #include <qdom.h>
 #include <qstringlist.h>
 
-KSpreadStyleManager::KSpreadStyleManager()
-  : m_defaultStyle( new KSpreadCustomStyle() )
+#include <kdebug.h>
+#include <klocale.h>
+
+#include <KoOasisStyles.h>
+#include <KoXmlNS.h>
+
+#include "kspread_doc.h"
+#include "kspread_style.h"
+#include "kspread_style_manager.h"
+
+using namespace KSpread;
+
+StyleManager::StyleManager()
+  : m_defaultStyle( new CustomStyle() )
 {
-  m_defaultStyle->setName( "Default" );
-  m_defaultStyle->setType( KSpreadStyle::BUILTIN );
 }
 
-KSpreadStyleManager::~KSpreadStyleManager()
+StyleManager::~StyleManager()
 {
   delete m_defaultStyle;
 
@@ -49,10 +52,11 @@ KSpreadStyleManager::~KSpreadStyleManager()
   }
 }
 
-void KSpreadStyleManager::saveOasis( KoGenStyles &mainStyles )
+void StyleManager::saveOasis( KoGenStyles &mainStyles )
 {
     kdDebug() << "Saving default oasis style" << endl;
-    m_defaultStyle->saveOasis( mainStyles );
+    KoGenStyle defaultStyle = KoGenStyle( Doc::STYLE_CELL_USER, "table-cell" );
+    m_defaultStyle->saveOasis( defaultStyle, mainStyles );
 
     Styles::iterator iter = m_styles.begin();
     Styles::iterator end  = m_styles.end();
@@ -60,67 +64,75 @@ void KSpreadStyleManager::saveOasis( KoGenStyles &mainStyles )
     while ( iter != end )
     {
         kdDebug() << "Saving style" << endl;
-        KSpreadCustomStyle * styleData = iter.data();
+        CustomStyle * styleData = iter.data();
 
-        styleData->saveOasis( mainStyles );
+        KoGenStyle customStyle = KoGenStyle( Doc::STYLE_CELL_USER, "table-cell" );
+        styleData->saveOasis( customStyle, mainStyles );
 
         ++iter;
     }
-
 }
 
-void KSpreadStyleManager::loadOasisStyleTemplate(  KoOasisStyles& oasisStyles )
+void StyleManager::loadOasisStyleTemplate( KoOasisStyles& oasisStyles )
 {
+    // loading default style first
+    const QDomElement* defaultStyle = oasisStyles.defaultStyle( "table-cell" );
+    if ( defaultStyle )
+    {
+      m_defaultStyle->loadOasis( oasisStyles, *defaultStyle, "Default" );
+      m_defaultStyle->setType( Style::BUILTIN );
+      kdDebug() << "StyleManager: default cell style loaded!" << endl;
+    }
+    else
+    {
+      delete m_defaultStyle;
+      m_defaultStyle = new CustomStyle();
+    }
+
     uint nStyles = oasisStyles.userStyles().count();
-    kdDebug()<<" number of template style to load : "<<nStyles<<endl;
+    kdDebug() << " number of template style to load : " << nStyles << endl;
     for (unsigned int item = 0; item < nStyles; item++) {
         QDomElement styleElem = oasisStyles.userStyles()[item];
-        QString name;
-        if ( styleElem.hasAttributeNS( KoXmlNS::style, "display-name" ) )
-        {
-            name = styleElem.attributeNS( KoXmlNS::style, "display-name", QString::null );
-        }
 
-        if ( name == "Default" )
+        // assume the name assigned by the application
+        QString name = styleElem.attributeNS( KoXmlNS::style, "name", QString::null );
+
+        // then replace by user-visible one (if any)
+        name = styleElem.attributeNS( KoXmlNS::style, "display-name", name );
+
+        if ( !name.isEmpty() )
         {
-            m_defaultStyle->loadOasis( oasisStyles, styleElem,name );
-            m_defaultStyle->setType( KSpreadStyle::BUILTIN );
-        }
-        else if ( !name.isEmpty() )
-        {
-            KSpreadCustomStyle * style = 0;
-            if ( styleElem.hasAttributeNS( KoXmlNS::style, "parent-style-name" ) && styleElem.attributeNS( KoXmlNS::style, "parent-style-name", QString::null ) == "Default" )
-                style = new KSpreadCustomStyle( name, m_defaultStyle );
+            CustomStyle * style = 0;
+            if ( styleElem.hasAttributeNS( KoXmlNS::style, "parent-style-name" ) )
+                // The style's parent name will be set in Style::loadOasis(..).
+                // After all styles are loaded the pointer to the parent is set.
+                style = new CustomStyle( name, 0 );
             else
-                style = new KSpreadCustomStyle( name, 0 );
+                style = new CustomStyle( name, m_defaultStyle );
 
             //fixme test return;
-            style->loadOasis( oasisStyles, styleElem,name );
-            style->setType( KSpreadStyle::CUSTOM );
+            style->loadOasis( oasisStyles, styleElem, name );
+            style->setType( Style::CUSTOM );
             m_styles[name] = style;
             kdDebug() << "Style " << name << ": " << style << endl;
-
         }
     }
+
+    // set the parent pointers after we loaded all styles
     Styles::iterator iter = m_styles.begin();
     Styles::iterator end  = m_styles.end();
-
     while ( iter != end )
     {
-        KSpreadCustomStyle * styleData = iter.data();
+        CustomStyle * styleData = iter.data();
 
         if ( !styleData->parent() && !styleData->parentName().isNull() )
             styleData->setParent( m_styles[ styleData->parentName() ] );
 
         ++iter;
     }
-
-    m_defaultStyle->setName( "Default" );
-    m_defaultStyle->setType( KSpreadStyle::BUILTIN );
-
 }
 
-QDomElement KSpreadStyleManager::save( QDomDocument & doc )
+QDomElement StyleManager::save( QDomDocument & doc )
 {
   kdDebug() << "Saving styles" << endl;
   QDomElement styles = doc.createElement( "styles" );
@@ -134,7 +146,7 @@ QDomElement KSpreadStyleManager::save( QDomDocument & doc )
   while ( iter != end )
   {
     kdDebug() << "Saving style" << endl;
-    KSpreadCustomStyle * styleData = iter.data();
+    CustomStyle * styleData = iter.data();
 
     styleData->save( doc, styles );
 
@@ -145,7 +157,7 @@ QDomElement KSpreadStyleManager::save( QDomDocument & doc )
   return styles;
 }
 
-bool KSpreadStyleManager::loadXML( QDomElement const & styles )
+bool StyleManager::loadXML( QDomElement const & styles )
 {
   QDomElement e = styles.firstChild().toElement();
   while ( !e.isNull() )
@@ -158,15 +170,15 @@ bool KSpreadStyleManager::loadXML( QDomElement const & styles )
     {
       if ( !m_defaultStyle->loadXML( e, name ) )
         return false;
-      m_defaultStyle->setType( KSpreadStyle::BUILTIN );
+      m_defaultStyle->setType( Style::BUILTIN );
     }
     else if ( !name.isNull() )
     {
-      KSpreadCustomStyle * style = 0;
+      CustomStyle * style = 0;
       if ( e.hasAttribute( "parent" ) && e.attribute( "parent" ) == "Default" )
-        style = new KSpreadCustomStyle( name, m_defaultStyle );
+        style = new CustomStyle( name, m_defaultStyle );
       else
-        style = new KSpreadCustomStyle( name, 0 );
+        style = new CustomStyle( name, 0 );
 
       if ( !style->loadXML( e, name ) )
       {
@@ -174,8 +186,8 @@ bool KSpreadStyleManager::loadXML( QDomElement const & styles )
         return false;
       }
 
-      if ( style->type() == KSpreadStyle::AUTO )
-        style->setType( KSpreadStyle::CUSTOM );
+      if ( style->type() == Style::AUTO )
+        style->setType( Style::CUSTOM );
       m_styles[name] = style;
       kdDebug() << "Style " << name << ": " << style << endl;
     }
@@ -188,7 +200,7 @@ bool KSpreadStyleManager::loadXML( QDomElement const & styles )
 
   while ( iter != end )
   {
-    KSpreadCustomStyle * styleData = iter.data();
+    CustomStyle * styleData = iter.data();
 
     if ( !styleData->parent() && !styleData->parentName().isNull() )
       styleData->setParent( m_styles[ styleData->parentName() ] );
@@ -197,48 +209,48 @@ bool KSpreadStyleManager::loadXML( QDomElement const & styles )
   }
 
   m_defaultStyle->setName( "Default" );
-  m_defaultStyle->setType( KSpreadStyle::BUILTIN );
+  m_defaultStyle->setType( Style::BUILTIN );
 
   return true;
 }
 
-void KSpreadStyleManager::createBuiltinStyles()
+void StyleManager::createBuiltinStyles()
 {
-  KSpreadCustomStyle * header1 = new KSpreadCustomStyle( i18n( "Header" ), m_defaultStyle );
+  CustomStyle * header1 = new CustomStyle( i18n( "Header" ), m_defaultStyle );
   QFont f( header1->font() );
   f.setItalic( true );
   f.setPointSize( f.pointSize() + 2 );
   f.setBold( true );
   header1->changeFont( f );
-  header1->setType( KSpreadStyle::BUILTIN );
+  header1->setType( Style::BUILTIN );
   m_styles[ header1->name() ] = header1;
 
-  KSpreadCustomStyle * header2 = new KSpreadCustomStyle( i18n( "Header1" ), header1 );
+  CustomStyle * header2 = new CustomStyle( i18n( "Header1" ), header1 );
   QColor color( "#F0F0FF" );
   header2->changeBgColor( color );
   QPen pen( Qt::black, 1, Qt::SolidLine );
   header2->changeBottomBorderPen( pen );
-  header2->setType( KSpreadStyle::BUILTIN );
+  header2->setType( Style::BUILTIN );
 
   m_styles[ header2->name() ] = header2;
 }
 
-KSpreadCustomStyle * KSpreadStyleManager::style( QString const & name ) const
+CustomStyle * StyleManager::style( QString const & name ) const
 {
   Styles::const_iterator iter( m_styles.find( name ) );
 
   if ( iter != m_styles.end() )
     return iter.data();
 
-  if ( name == i18n( "Default" ) || name == "Default" )
+  if ( name == "Default" )
     return m_defaultStyle;
 
   return 0;
 }
 
-void KSpreadStyleManager::takeStyle( KSpreadCustomStyle * style )
+void StyleManager::takeStyle( CustomStyle * style )
 {
-  KSpreadCustomStyle * parent = style->parent();
+  CustomStyle * parent = style->parent();
 
   Styles::iterator iter = m_styles.begin();
   Styles::iterator end  = m_styles.end();
@@ -260,9 +272,9 @@ void KSpreadStyleManager::takeStyle( KSpreadCustomStyle * style )
   }
 }
 
-bool KSpreadStyleManager::checkCircle( QString const & name, QString const & parent )
+bool StyleManager::checkCircle( QString const & name, QString const & parent )
 {
-  KSpreadCustomStyle * s = style( parent );
+  CustomStyle * s = style( parent );
   if ( !s || s->parent() == 0 )
     return true;
   if ( s->parentName() == name )
@@ -271,9 +283,9 @@ bool KSpreadStyleManager::checkCircle( QString const & name, QString const & par
     return checkCircle( name, s->parentName() );
 }
 
-bool KSpreadStyleManager::validateStyleName( QString const & name, KSpreadCustomStyle * style )
+bool StyleManager::validateStyleName( QString const & name, CustomStyle * style )
 {
-  if ( m_defaultStyle->name() == name || name == i18n( "Default" ) )
+  if ( m_defaultStyle->name() == name || name == "Default" )
     return false;
 
   Styles::const_iterator iter = m_styles.begin();
@@ -290,7 +302,7 @@ bool KSpreadStyleManager::validateStyleName( QString const & name, KSpreadCustom
   return true;
 }
 
-void KSpreadStyleManager::changeName( QString const & oldName, QString const & newName )
+void StyleManager::changeName( QString const & oldName, QString const & newName )
 {
   Styles::iterator iter = m_styles.begin();
   Styles::iterator end  = m_styles.end();
@@ -306,17 +318,17 @@ void KSpreadStyleManager::changeName( QString const & oldName, QString const & n
   iter = m_styles.find( oldName );
   if ( iter != end )
   {
-    KSpreadCustomStyle * s = iter.data();
+    CustomStyle * s = iter.data();
     m_styles.erase( iter );
     m_styles[newName] = s;
   }
 }
 
-QStringList KSpreadStyleManager::styleNames() const
+QStringList StyleManager::styleNames() const
 {
   QStringList list;
 
-  list.push_back( i18n( "Default" ) );
+  list.push_back( "Default" );
 
   Styles::const_iterator iter = m_styles.begin();
   Styles::const_iterator end  = m_styles.end();
