@@ -1,5 +1,5 @@
 /*
-    $Id: stats.h 212185 2003-03-07 22:11:39Z waba $
+    $Id: stats.h 466447 2005-10-02 17:54:10Z zander $
 
     KCalc, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -19,7 +19,8 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 
 */
 
