@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef KWORD_TABLEFRAMESET_IFACE_H
@@ -39,11 +39,9 @@ k_dcop:
     uint nbRows();
     uint numCols();
     uint numCells() ;
-    bool hasSelectedFrame();
-    void deselectAll();
     //return reference to a cell
-    DCOPRef getCell( int pos );
-    DCOPRef getCell( uint row, uint col );
+    DCOPRef cell( int pos );
+    DCOPRef cell( uint row, uint col );
     DCOPRef startEditingCell(uint row, uint col );
 
 private:
