@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef CONTEXTSTYLE_H
@@ -29,8 +29,7 @@
 
 //KDE Include
 #include <kconfig.h>
-//#include <kozoomhandler.h>
-#include "kozoomhandler.h"
+#include <KoTextZoomHandler.h>
 
 //Formula include
 #include "kformuladefs.h"
@@ -50,7 +49,7 @@ class SymbolTable;
  * All distances are stored in point. Most methods return pixel
  * values.
  */
-class ContextStyle : public KoZoomHandler
+class ContextStyle : public KoTextZoomHandler
 {
 public:
 
@@ -83,8 +82,17 @@ public:
     ContextStyle();
     ~ContextStyle();
 
-    void init();
-    void readConfig( KConfig* config );
+    /**
+     * @param init if true fonts may be installed if needed.
+     */
+    void init( bool init = true );
+
+    /**
+     * @param init true if initialization may take place. This may cause font
+     * installation. Mark as false when this is not intended (i. e. creating
+     * configuration dialog from another component)
+     */
+    void readConfig( KConfig* config, bool init = true );
 
     bool edit() const { return m_edit; }
     void setEdit( bool e ) { m_edit = e; }
@@ -128,7 +136,7 @@ public:
     void setHelpColor( const QColor& );
 
     QString getFontStyle() const { return m_fontStyleName; }
-    void setFontStyle( const QString& fontStyle );
+    void setFontStyle( const QString& fontStyle, bool init = true );
 
     QFont getDefaultFont()    const { return defaultFont; }
     QFont getNameFont()       const { return nameFont; }
