@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <qpainter.h>
@@ -165,15 +165,17 @@ void Artwork::calcSizes( const ContextStyle& style,
 }
 
 
-void Artwork::draw(QPainter& painter, const LuPixelRect& r,
+void Artwork::draw(QPainter& painter, const LuPixelRect& /*r*/,
                    const ContextStyle& style, ContextStyle::TextStyle tstyle,
                    const LuPixelPoint& parentOrigin)
 {
     luPt mySize = style.getAdjustedSize( tstyle );
     luPixel myX = parentOrigin.x() + getX();
     luPixel myY = parentOrigin.y() + getY();
+    /*
     if ( !LuPixelRect( myX, myY, getWidth(), getHeight() ).intersects( r ) )
         return;
+    */
 
     painter.setPen(style.getDefaultColor());
 
