@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef FORMULACURSOR_H
@@ -104,7 +104,7 @@ public:
      * Draws the cursor at its current position.
      * The cursor will always be drawn in xor mode.
      */
-    void draw( QPainter&, const ContextStyle& context, bool smallCursor );
+    void draw( QPainter&, const ContextStyle& context, bool smallCursor, bool activeCursor );
 
 
     // simple cursor movement.
