@@ -14,15 +14,18 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <iostream>
 #include <qstring.h>
 #include <qfontmetrics.h>
 
-//#include <koUnit.h>
+#include <klocale.h>
+#include <kmessagebox.h>
+
+//#include <KoUnit.h>
 
 #include "kformulamathmlread.h"
 #include "symboltable.h"
@@ -37,7 +40,7 @@ class MathML2KFormulaPrivate
 public:
     MathML2KFormulaPrivate( MathML2KFormula* mml_filter,
                             const ContextStyle& contextStyle,
-                            QDomDocument formuladoc );
+                            const QDomDocument& formuladoc );
     ~MathML2KFormulaPrivate();
 
     void math( QDomElement element );
@@ -66,9 +69,9 @@ public:
     // Script and Limit Schemata
     void msub_msup( QDomElement element, QDomNode docnode );
     void msubsup( QDomElement element, QDomNode docnode );
-    void munder( QDomElement element, QDomNode docnode );
-    void mover( QDomElement element, QDomNode docnode );
-    void munderover( QDomElement element, QDomNode docnode );
+    void munder( QDomElement element, QDomNode docnode, bool oasisFormat );
+    void mover( QDomElement element, QDomNode docnode, bool oasisFormat );
+    void munderover( QDomElement element, QDomNode docnode, bool oasisFormat );
     // mmultiscripts not supported
 
     // Tables and Matrices
@@ -81,8 +84,8 @@ public:
 protected:
     void createTextElements( QString text, QDomNode docnode );
     double convertToPoint( QString value, bool* ok );
-    bool isEmbellishedOperator( QDomNode node, QDomElement* mo );
-    bool isSpaceLike( QDomNode node );
+    bool isEmbellishedOperator( QDomNode node, QDomElement* mo, bool oasisFormat );
+    bool isSpaceLike( QDomNode node, bool oasisFormat );
 
     enum MathVariant {
         normal,
@@ -180,6 +183,8 @@ protected:
                     break;
 
                 //case monospace:
+                default:
+                    break;
                 }
             }
 
@@ -251,7 +256,7 @@ private:
     MathML2KFormula* filter;
 };
 
-MathML2KFormulaPrivate::MathML2KFormulaPrivate( MathML2KFormula* mml_filter, const ContextStyle& cs, QDomDocument formuladoc )
+MathML2KFormulaPrivate::MathML2KFormulaPrivate( MathML2KFormula* mml_filter, const ContextStyle& cs, const QDomDocument& formuladoc )
     : doc( formuladoc ), context( cs ), filter( mml_filter )
 {
 }
@@ -339,7 +344,7 @@ void MathML2KFormulaPrivate::mtext( QDomElement element, QDomNode docnode )
             filter->processElement( n, doc, docnode );
         }
         else {
-            kdDebug( DEBUGID ) << "<mtext> child: " << n.nodeType() << endl;
+            kdDebug( DEBUGID ) << "<mtext> child: " << n.nodeName() << endl;
         }
 
         n = n.nextSibling();
@@ -461,7 +466,7 @@ void MathML2KFormulaPrivate::mrow( QDomElement element, QDomNode docnode )
             filter->processElement( e, doc, docnode );
         }
         else {
-            kdDebug( DEBUGID ) << "<mrow> child: " << n.nodeType() << endl;
+            kdDebug( DEBUGID ) << "<mrow> child: " << n.nodeName() << endl;
         }
         n = n.nextSibling();
     }
@@ -502,7 +507,7 @@ void MathML2KFormulaPrivate::mfrac( QDomElement element, QDomNode docnode )
             }
         }
         else {
-            kdDebug( DEBUGID ) << "<mfrac> child: " << n.nodeType() << endl;
+            kdDebug( DEBUGID ) << "<mfrac> child: " << n.nodeName() << endl;
         }
         n = n.nextSibling();
     }
@@ -546,7 +551,7 @@ void MathML2KFormulaPrivate::mroot( QDomElement element, QDomNode docnode )
             }
         }
         else {
-            kdDebug( DEBUGID ) << "<mroot> child: " << n.nodeType() << endl;
+            kdDebug( DEBUGID ) << "<mroot> child: " << n.nodeName() << endl;
         }
         n = n.nextSibling();
     }
@@ -568,7 +573,7 @@ void MathML2KFormulaPrivate::msqrt( QDomElement element, QDomNode docnode )
             filter->processElement( n.toElement(), doc, sequence );
         }
         else {
-            kdDebug( DEBUGID ) << "<msqrt> child: " << n.nodeType() << endl;
+            kdDebug( DEBUGID ) << "<msqrt> child: " << n.nodeName() << endl;
         }
         n = n.nextSibling();
     }
@@ -698,7 +703,7 @@ void MathML2KFormulaPrivate::mfenced( QDomElement element, QDomNode docnode )
             filter->processElement( e, doc, sequence );
         }
         else {
-            kdDebug( DEBUGID ) << "<mfenced> child: " << n.nodeType() << endl;
+            kdDebug( DEBUGID ) << "<mfenced> child: " << n.nodeName() << endl;
         }
         n = n.nextSibling();
     }
@@ -748,7 +753,7 @@ void MathML2KFormulaPrivate::mtable( QDomElement element, QDomNode docnode )
             }
         }
         else {
-            kdDebug( DEBUGID ) << "<mtable> child: " << n.nodeType() << endl;
+            kdDebug( DEBUGID ) << "<mtable> child: " << n.nodeName() << endl;
         }
         n = n.nextSibling();
     }
@@ -834,14 +839,14 @@ void MathML2KFormulaPrivate::msub_msup( QDomElement element, QDomNode docnode )
         }
         else {
             kdDebug( DEBUGID ) << "<" << element.tagName() << "> child: "
-                               << n.nodeType() << endl;
+                               << n.nodeName() << endl;
         }
         n = n.nextSibling();
     }
     docnode.appendChild( root );
 }
 
-void MathML2KFormulaPrivate::munder( QDomElement element, QDomNode docnode )
+void MathML2KFormulaPrivate::munder( QDomElement element, QDomNode docnode, bool oasisFormat )
 {
     bool accentunder;
 
@@ -855,7 +860,7 @@ void MathML2KFormulaPrivate::munder( QDomElement element, QDomNode docnode )
 
         QDomElement mo;
         // is underscript an embellished operator?
-        if ( isEmbellishedOperator( element.childNodes().item( 1 ), &mo ) ) {
+        if ( isEmbellishedOperator( element.childNodes().item( 1 ), &mo, oasisFormat ) ) {
             if ( mo.attribute( "accent" ) == "true" )
                 accentunder = true;
             else
@@ -890,7 +895,7 @@ void MathML2KFormulaPrivate::munder( QDomElement element, QDomNode docnode )
                 }
 
                 QDomElement mo; QDomElement index;
-                if ( isEmbellishedOperator( n.previousSibling(), &mo ) &&
+                if ( isEmbellishedOperator( n.previousSibling(), &mo, oasisFormat ) &&
                      !previousStyle.displaystyle &&
                      mo.attribute( "movablelimits" ) == "true" )
                 {
@@ -911,7 +916,7 @@ void MathML2KFormulaPrivate::munder( QDomElement element, QDomNode docnode )
         }
         else {
             kdDebug( DEBUGID ) << "<" << element.tagName() << "> child: "
-                               << n.nodeType() << endl;
+                               << n.nodeName() << endl;
         }
         n = n.nextSibling();
     }
@@ -919,7 +924,7 @@ void MathML2KFormulaPrivate::munder( QDomElement element, QDomNode docnode )
     docnode.appendChild( root );
 }
 
-void MathML2KFormulaPrivate::mover( QDomElement element, QDomNode docnode )
+void MathML2KFormulaPrivate::mover( QDomElement element, QDomNode docnode, bool oasisFormat )
 {
     bool accent;
 
@@ -933,7 +938,7 @@ void MathML2KFormulaPrivate::mover( QDomElement element, QDomNode docnode )
 
         QDomElement mo;
         // is overscript an embellished operator?
-        if ( isEmbellishedOperator( element.childNodes().item( 1 ), &mo ) ) {
+        if ( isEmbellishedOperator( element.childNodes().item( 1 ), &mo, oasisFormat ) ) {
             if ( mo.attribute( "accent" ) == "true" )
                 accent = true;
             else
@@ -968,7 +973,7 @@ void MathML2KFormulaPrivate::mover( QDomElement element, QDomNode docnode )
                 }
 
                 QDomElement mo; QDomElement index;
-                if ( isEmbellishedOperator( n.previousSibling(), &mo ) &&
+                if ( isEmbellishedOperator( n.previousSibling(), &mo, oasisFormat ) &&
                      !previousStyle.displaystyle &&
                      mo.attribute( "movablelimits" ) == "true" )
                 {
@@ -989,7 +994,7 @@ void MathML2KFormulaPrivate::mover( QDomElement element, QDomNode docnode )
         }
         else {
             kdDebug( DEBUGID ) << "<" << element.tagName() << "> child: "
-                               << n.nodeType() << endl;
+                               << n.nodeName() << endl;
         }
         n = n.nextSibling();
     }
@@ -997,8 +1002,7 @@ void MathML2KFormulaPrivate::mover( QDomElement element, QDomNode docnode )
     docnode.appendChild( root );
 }
 
-void MathML2KFormulaPrivate::munderover( QDomElement element,
-                                         QDomNode docnode )
+void MathML2KFormulaPrivate::munderover( QDomElement element, QDomNode docnode, bool oasisFormat )
 {
     bool accent;
     bool accentunder;
@@ -1013,7 +1017,7 @@ void MathML2KFormulaPrivate::munderover( QDomElement element,
 
         QDomElement mo;
         // is underscript an embellished operator?
-        if ( isEmbellishedOperator( element.childNodes().item( 1 ), &mo ) ) {
+        if ( isEmbellishedOperator( element.childNodes().item( 1 ), &mo, oasisFormat ) ) {
             if ( mo.attribute( "accent" ) == "true" )
                 accentunder = true;
             else
@@ -1032,7 +1036,7 @@ void MathML2KFormulaPrivate::munderover( QDomElement element,
 
         QDomElement mo;
         // is overscript an embellished operator?
-        if ( isEmbellishedOperator( element.childNodes().item( 2 ), &mo ) ) {
+        if ( isEmbellishedOperator( element.childNodes().item( 2 ), &mo,oasisFormat ) ) {
             kdDebug( DEBUGID ) << "embellished operator" << endl;
             if ( mo.attribute( "accent" ) == "true" )
                 accent = true;
@@ -1071,7 +1075,7 @@ void MathML2KFormulaPrivate::munderover( QDomElement element,
 
                 QDomElement mo; QDomElement index;
                 // is the base an embellished operator?
-                if ( isEmbellishedOperator( element.firstChild(), &mo ) &&
+                if ( isEmbellishedOperator( element.firstChild(), &mo, oasisFormat ) &&
                      !previousStyle.displaystyle &&
                      mo.attribute( "movablelimits" ) == "true" )
                 {
@@ -1098,7 +1102,7 @@ void MathML2KFormulaPrivate::munderover( QDomElement element,
                 }
 
                 QDomElement mo; QDomElement index;
-                if ( isEmbellishedOperator( element.firstChild(), &mo ) &&
+                if ( isEmbellishedOperator( element.firstChild(), &mo, oasisFormat ) &&
                      !previousStyle.displaystyle &&
                      mo.attribute( "movablelimits" ) == "true" )
                 {
@@ -1119,7 +1123,7 @@ void MathML2KFormulaPrivate::munderover( QDomElement element,
         }
         else {
             kdDebug( DEBUGID ) << "<" << element.tagName() << "> child: "
-                               << n.nodeType() << endl;
+                               << n.nodeName() << endl;
         }
         n = n.nextSibling();
     }
@@ -1175,15 +1179,14 @@ void MathML2KFormulaPrivate::msubsup( QDomElement element, QDomNode docnode )
             }
         }
         else {
-            kdDebug( DEBUGID ) << "<msubsup> child: " << n.nodeType() << endl;
+            kdDebug( DEBUGID ) << "<msubsup> child: " << n.nodeName() << endl;
         }
         n = n.nextSibling();
     }
     docnode.appendChild( root );
 }
 
-void MathML2KFormulaPrivate::createTextElements( QString text,
-                                                 QDomNode docnode )
+void MathML2KFormulaPrivate::createTextElements( QString text, QDomNode docnode )
 {
     for ( uint i = 0; i < text.length(); ++i ) {
         QDomElement textelement = doc.createElement( "TEXT" );
@@ -1247,7 +1250,7 @@ double MathML2KFormulaPrivate::convertToPoint( QString value, bool* ok )
 }
 
 bool MathML2KFormulaPrivate::isEmbellishedOperator( QDomNode node,
-                                                    QDomElement* mo )
+                                                    QDomElement* mo, bool oasisFormat )
 {
     // See MathML 2.0 specification: 3.2.5.7
 
@@ -1266,23 +1269,22 @@ bool MathML2KFormulaPrivate::isEmbellishedOperator( QDomNode node,
          tag == "munder" || tag == "mover" || tag == "munderover" ||
          tag == "mmultiscripts" || tag == "mfrac" || tag == "semantics" )
     {
-        return isEmbellishedOperator( element.firstChild(), mo );
+        return isEmbellishedOperator( element.firstChild(), mo,oasisFormat );
     }
     if ( tag == "maction" )
     {
         return false; // not supported
     }
-    if ( tag == "mrow" || tag == "mstyle" || tag == "mphantom" ||
-         tag == "mpadded" ) {
+    if ( tag == "mrow"  || tag == "mstyle" || tag == "mphantom" || tag == "mpadded" ) {
         QDomNode n = element.firstChild();
         int i = 0;
 
         while ( !n.isNull() ) {
-            if ( isEmbellishedOperator( n, mo ) ) {
+            if ( isEmbellishedOperator( n, mo,oasisFormat ) ) {
                 if ( ++i > 1 ) // one (only one) embellished operator
                     return false;
             }
-            else if ( !isSpaceLike( n ) ) { // zero or more space-like elements
+            else if ( !isSpaceLike( n, oasisFormat ) ) { // zero or more space-like elements
                 return false;
             }
             n = n.nextSibling();
@@ -1292,7 +1294,7 @@ bool MathML2KFormulaPrivate::isEmbellishedOperator( QDomNode node,
     return false;
 }
 
-bool MathML2KFormulaPrivate::isSpaceLike( QDomNode node )
+bool MathML2KFormulaPrivate::isSpaceLike( QDomNode node, bool oasisFormat )
 {
     // See MathML 2.0 specification: 3.2.7.3
 
@@ -1306,11 +1308,10 @@ bool MathML2KFormulaPrivate::isSpaceLike( QDomNode node )
          tag == "maligngroup" || tag == "malignmark" ) {
         return true;
     }
-    if ( tag == "mstyle" || tag == "mphantom" || tag == "mpadded" ||
-         tag == "mrow" ) {
+    if ( tag == "mstyle" || tag == "mphantom" || tag == "mpadded" || tag == "mrow" ) {
         QDomNode n = element.firstChild();
         while ( !n.isNull() ) {
-            if ( isSpaceLike( n ) )
+            if ( isSpaceLike( n,oasisFormat ) )
                 n = n.nextSibling();
             else
                 return false;
@@ -1325,11 +1326,10 @@ bool MathML2KFormulaPrivate::isSpaceLike( QDomNode node )
 }
 
 
-MathML2KFormula::MathML2KFormula( QDomDocument mmldoc, const ContextStyle &contextStyle )
-    : context( contextStyle )
+MathML2KFormula::MathML2KFormula( const QDomDocument& mmldoc, const ContextStyle &contextStyle, bool _oasisFormat )
+    : m_error( false ), origdoc( mmldoc ), oasisFormat( _oasisFormat ), context( contextStyle )
 {
     done = false;
-    origdoc = mmldoc;
 }
 
 QDomDocument MathML2KFormula::getKFormulaDom()
@@ -1342,22 +1342,24 @@ QDomDocument MathML2KFormula::getKFormulaDom()
 void MathML2KFormula::startConversion()
 {
     //TODO:let it be async
+    //kdDebug() << origdoc.toString() << endl;
     done = false;
     formuladoc = QDomDocument( "KFORMULA" );
     impl = new MathML2KFormulaPrivate( this, context, formuladoc );
     QDomElement element = origdoc.documentElement();
     if ( element.tagName() == "math" ) {
         impl->math( element );
+        m_error = false;
     }
     else {
-        kdDebug() << "Fatal error: Not a MathML document!" << endl;
+        kdError() << "Not a MathML document!" << endl;
+        KMessageBox::error( 0, i18n( "The document does not seem to be MathML." ), i18n( "MathML Import Error" ) );
+        m_error = true;
     }
-    //cerr << formuladoc.toCString() << endl;
     done = true;
 }
 
-bool MathML2KFormula::processElement( QDomNode node, QDomDocument doc,
-                                      QDomNode docnode )
+bool MathML2KFormula::processElement( QDomNode node, QDomDocument& doc, QDomNode docnode )
 {
 
     //QDomElement *element;
@@ -1422,33 +1424,70 @@ bool MathML2KFormula::processElement( QDomNode node, QDomDocument doc,
             impl->mtable( element, docnode );
 	}
 
-	else if ( tag == "msub" || tag == "msup" ) {
+	else if ( tag == "msub"  || tag == "msup" ) {
 	    type = SCRIPT;
             impl->msub_msup( element, docnode );
 	}
 
 	else if ( tag == "munder" ) {
 	    type = SCRIPT;
-            impl->munder( element, docnode );
+            impl->munder( element, docnode,oasisFormat );
 	}
         else if ( tag == "mover" ) {
 	    type = SCRIPT;
-            impl->mover( element, docnode );
+            impl->mover( element, docnode,oasisFormat );
 	}
         else if ( tag == "munderover" ) {
             type = SCRIPT;
-            impl->munderover( element, docnode );
+            impl->munderover( element, docnode, oasisFormat );
         }
 	else if ( tag == "msubsup" ) {
 	    type = SCRIPT;
             impl->msubsup( element, docnode );
 	}
 
-        // content markup (not yet usable)
+        // content markup (not yet complete)
         else if ( tag == "apply" ) {
             type = CONTENT;
             QDomNode n = element.firstChild();
             QDomElement op = n.toElement();
+                uint count = element.childNodes().count();
+		//adding explicit brackets to replace "apply"s implicit ones
+		QDomElement brackets = doc.createElement("BRACKET");
+		brackets.setAttribute("RIGHT", "41");
+		brackets.setAttribute("LEFT", "40");
+		QDomElement content = doc.createElement("CONTENT");
+		brackets.appendChild(content);
+		QDomElement base = doc.createElement("SEQUENCE");
+		content.appendChild(base);
+		docnode.appendChild(brackets);
+		//Arithmetic, Algebra and Logic operators status
+		// quotient	X
+		// factorial	O
+		// divide	O
+		// max, min	X
+		// minus	O
+		// plus		O
+		// power	O
+		// rem		X
+		// times	O
+		// root		X
+		// gcd		X
+		// and		O
+		// or		O
+		// xor		O
+		// not		O
+		// implies	O
+		// forall	X
+		// exists	X
+		// abs		O
+		// conjugate	X
+		// arg		X
+		// real		X
+		// imaginary	X
+		// lcm		X
+		// floor	X
+		// ceiling	X
 
             // n-ary
             if ( op.tagName() == "plus" || op.tagName() == "times" ||
@@ -1473,14 +1512,14 @@ bool MathML2KFormula::processElement( QDomNode node, QDomDocument doc,
                             else if ( op.tagName() == "or" )
                                 value = "|";
                             else if ( op.tagName() == "xor" )
-                                value = "#"; // ???
+                                value = "^"; // ???
 
-                            text.setAttribute( "CHAR", value );
-                            docnode.appendChild( text );
+                            text.setAttribute( "CHAR", value );	//switch to createTextElements?
+                            base.appendChild( text );
                         }
                         first = false;
                         QDomElement e = n.toElement();
-                        processElement( e, doc, docnode );
+                        processElement( e, doc, base );
                     }
                     n = n.nextSibling();
                 }
@@ -1489,27 +1528,81 @@ bool MathML2KFormula::processElement( QDomNode node, QDomDocument doc,
             else if ( op.tagName() == "factorial" ) {
                 QDomElement e = n.nextSibling().toElement();
                 processElement( e, doc, docnode );
-                impl->createTextElements( "!", docnode );
+                impl->createTextElements( "!", base );
             }
             else if ( op.tagName() == "minus" ) {
-                uint count = op.childNodes().count();
                 n = n.nextSibling();
                 if ( count == 2 ) { // unary
-                    impl->createTextElements( "-", docnode );
+                    impl->createTextElements( "-", base );
                     QDomElement e = n.toElement();
-                    processElement( e, doc, docnode );
+                    processElement( e, doc, base );
                 }
                 else if ( count == 3 ) { // binary
-                    n = n.nextSibling();
                     QDomElement e = n.toElement();
-                    processElement( e, doc, docnode );
-                    impl->createTextElements( "-", docnode );
+                    processElement( e, doc, base );
+                    impl->createTextElements( "-", base );
                     n = n.nextSibling();
                     e = n.toElement();
-                    processElement( e, doc, docnode );
+                    processElement( e, doc, base );
                 }
             }
 
+		else if ( op.tagName() == "divide" && count == 3 ) {
+			n = n.nextSibling();
+        	        QDomElement e = n.toElement();
+			processElement( e, doc, base );
+			impl->createTextElements("/", base);
+			n = n.nextSibling();
+			e = n.toElement();
+			processElement( e, doc, base );
+		}
+		else if ( op.tagName() == "power" && count == 3 ) {
+			//code duplication of msub_sup(), but I can't find a way to cleanly call it
+			n = n.nextSibling();
+        	        QDomElement e = n.toElement();
+			QDomElement index = doc.createElement("INDEX");
+			base.appendChild(index);
+			QDomElement content = doc.createElement("CONTENT");
+			index.appendChild(content);
+			QDomElement sequence = doc.createElement("SEQUENCE");
+			content.appendChild(sequence);
+			processElement(e, doc, sequence);
+			QDomElement upper = doc.createElement("UPPERRIGHT");
+			index.appendChild(upper);
+			sequence = doc.createElement("SEQUENCE");
+			upper.appendChild(sequence);
+			n = n.nextSibling();
+        	        e = n.toElement();
+			processElement(e, doc, sequence);
+		}
+		else if ( op.tagName() == "abs" && count == 2) {
+			n = n.nextSibling();
+        	        QDomElement e = n.toElement();
+			QDomElement bracket = doc.createElement("BRACKET");
+			bracket.setAttribute("RIGHT", "257");
+			bracket.setAttribute("LEFT", "256");
+			base.appendChild(bracket);
+			QDomElement content = doc.createElement("CONTENT");
+			bracket.appendChild(content);
+			QDomElement sequence = doc.createElement("SEQUENCE");
+			content.appendChild(sequence);
+			processElement(e, doc, sequence);
+		}
+		else if ( op.tagName() == "not" && count == 2) {
+			n = n.nextSibling();
+        	        QDomElement e = n.toElement();
+			impl->createTextElements(QString(QChar(0xAC)), base);
+			processElement(e, doc, base);
+		}
+		else if ( op.tagName() == "implies" && count == 3 ) {
+			n = n.nextSibling();
+        	        QDomElement e = n.toElement();
+			processElement( e, doc, base );
+			impl->createTextElements(QString(QChar(0x21D2)), base);
+			n = n.nextSibling();
+			e = n.toElement();
+			processElement( e, doc, base );
+		}
             // many, many more...
 
         }
@@ -1661,7 +1754,7 @@ bool MathML2KFormula::processElement( QDomNode node, QDomDocument doc,
     }
 
     if ( type == UNKNOWN && node.nodeType() != QDomNode::AttributeNode ) {
-        cerr << "Not an element: " << node.nodeType() << endl;
+        kdDebug() << "Not an element: " << node.nodeName() << endl;
 	QDomNode n = node.firstChild();
 	while ( !n.isNull() ) {
 	    processElement( n, doc, docnode );
