@@ -919,14 +919,13 @@ bool KoDocument::saveExternalChildren()
     }
 
     //kdDebug(30003)<<k_funcinfo<<" checking children of doc='"<<url().url()<<"'"<<endl;
-    KoDocument *doc;
     KoDocumentChild *ch;
     QPtrListIterator<KoDocumentChild> it = children();
     for (; (ch = it.current()); ++it )
     {
         if ( !ch->isDeleted() )
         {
-            doc = ch->document();
+            KoDocument* doc = ch->document();
             if ( doc && doc->isStoredExtern() && doc->isModified() )
             {
                 kdDebug(30003)<<" save external doc='"<<url().url()<<"'"<<endl;
@@ -936,7 +935,7 @@ bool KoDocument::saveExternalChildren()
             }
             //kdDebug(30003)<<k_funcinfo<<" not modified doc='"<<url().url()<<"'"<<endl;
             // save possible external docs inside doc
-            if ( !doc->saveExternalChildren() )
+            if ( doc && !doc->saveExternalChildren() )
                 return false;
         }
     }
