@@ -1,5 +1,5 @@
 /*
-   $Id: main.h 275870 2004-01-01 15:03:35Z goutte $
+   $Id: main.h 466447 2005-10-02 17:54:10Z zander $
    This file is part of the KDE project
    Copyright (C) 2001,2002 Daniel Naber <daniel.naber@t-online.de>
 */
@@ -16,7 +16,8 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  ***************************************************************************/
 
 #ifndef __main_h__
